@@ -3,7 +3,7 @@
 # Check for files with CRLF line terminators
 
 r=0
-for f in $fldigi_SOURCES $EXTRA_fldigi_SOURCES $EXTRA_DIST; do
+for f in $fldigi_SOURCES $flarq_SOURCES $EXTRA_fldigi_SOURCES $EXTRA_DIST; do
     base=$(echo $f | sed -n '/\.[cC][cCpPxX]\{1,\}/ { s!.*/\(.*\)\.[^.]*$!\1!; p }')
     if test "x$base" != "x" && grep "
 " "${srcdir}/${f}" >/dev/null; then
