@@ -3,7 +3,7 @@
 //
 // Copyright (C) 2012
 //		Dave Freese, W1HKJ
-//		Stefan Fendt, DO2SMF
+//		Stefan Fendt, DL1SMF
 //
 // This file is part of fldigi.
 //
@@ -45,6 +45,7 @@ using namespace std;
 #include "debug.h"
 #include "synop.h"
 #include "main.h"
+#include "modem.h"
 
 #define FILTER_DEBUG 0
 
@@ -85,6 +86,10 @@ void rtty::tx_init(SoundBase *sc)
 	phaseacc = 0;
 	preamble = true;
 	videoText();
+
+	symbols = 0;
+	acc_symbols = 0;
+	ovhd_symbols = 0;
 }
 
 // Customizes output of Synop decoded data.
@@ -168,7 +173,7 @@ void rtty::init()
 		set_scope_mode(Digiscope::XHAIRS);
 	else
 		set_scope_mode(Digiscope::RTTY);
-	for (int i = 0; i < MAXPIPE; i++) mark_history[i] = space_history[i] = complex(0,0);
+	for (int i = 0; i < MAXPIPE; i++) mark_history[i] = space_history[i] = cmplx(0,0);
 
 	lastchar = 0;
 }
@@ -190,21 +195,17 @@ void rtty::reset_filters()
 	int filter_length = 1024;
 
 	if (mark_filt) {
-		mark_filt->rtty_order(rtty_baud/samplerate, 0,
-			progdefaults.rtty_filter, 1.0);
+		mark_filt->rtty_filter(rtty_baud/samplerate);
 	} else {
 		mark_filt = new fftfilt(rtty_baud/samplerate, filter_length);
-		mark_filt->rtty_order(rtty_baud/samplerate, 0,
-			progdefaults.rtty_filter, 1.0);
+		mark_filt->rtty_filter(rtty_baud/samplerate);
      }
 
 	if (space_filt) {
-		space_filt->rtty_order(rtty_baud/samplerate, 0,
-			progdefaults.rtty_filter, 1.0);
+		space_filt->rtty_filter(rtty_baud/samplerate);
 	} else {
 		space_filt = new fftfilt(rtty_baud/samplerate, filter_length);
-		space_filt->rtty_order(rtty_baud/samplerate, 0,
-			progdefaults.rtty_filter, 1.0);
+		space_filt->rtty_filter(rtty_baud/samplerate);
      }
 }
 
@@ -266,7 +267,8 @@ void rtty::restart()
 		snprintf(msg1, sizeof(msg1), "%-4.2f/%-4.0f", rtty_baud, rtty_shift);
 	put_Status1(msg1);
 	put_MODEstatus(mode);
-	for (int i = 0; i < MAXPIPE; i++) QI[i].re = QI[i].im = 0.0;
+	for (int i = 0; i < MAXPIPE; i++) 
+		QI[i] = cmplx(0.0, 0.0);
 	sigpwr = 0.0;
 	noisepwr = 0.0;
 	sigsearch = 0;
@@ -289,7 +291,7 @@ void rtty::restart()
 
 	inp_ptr = 0;
 
-	for (int i = 0; i < MAXPIPE; i++) mark_history[i] = space_history[i] = complex(0,0);
+	for (int i = 0; i < MAXPIPE; i++) mark_history[i] = space_history[i] = cmplx(0,0);
 
 	rttyviewer->restart();
 	progStatus.rtty_filter_changed = false;
@@ -340,9 +342,9 @@ void rtty::Clear_syncscope()
 	set_scope(0, 0, false);
 }
 
-complex rtty::mixer(double &phase, double f, complex in)
+cmplx rtty::mixer(double &phase, double f, cmplx in)
 {
-	complex z = complex( cos(phase), sin(phase)) * in;
+	cmplx z = cmplx( cos(phase), sin(phase)) * in;
 
 	phase -= TWOPI * f / samplerate;
 	if (phase < -TWOPI) phase += TWOPI;
@@ -579,15 +581,14 @@ int rtty::rx_process(const double *buf, int len)
 	int length = len;
 	static int showxy = symbollen;
 
-	complex z, zmark, zspace, *zp_mark, *zp_space;
+	cmplx z, zmark, zspace, *zp_mark, *zp_space;
 
 	int n_out = 0;
 	static int bitcount = 5 * nbits * symbollen;
 
-	if (rttyviewer && !bHistory && 
-		(!progdefaults.report_when_visible ||
-		 (progdefaults.report_when_visible && (dlgViewer->visible() || progStatus.show_channels))))
-		rttyviewer->rx_process(buf, len);
+	if ( !progdefaults.report_when_visible ||
+		 dlgViewer->visible() || progStatus.show_channels )
+		if (!bHistory && rttyviewer) rttyviewer->rx_process(buf, len);
 
 	if (progStatus.rtty_filter_changed) {
 		progStatus.rtty_filter_changed = false;
@@ -606,16 +607,16 @@ double value;
 if (snum < 2 * filter_length) {
 	frequency = 1000.0;
 	ook(snum);
-//	z.re = z.im = (snum/symbollen % 2 == 0) ? 1.0 : 0.0;
-	z.re = z.im = value;
-	ook_signal << snum << "," << z.re << ",";
+	z = complex(value, value);
+	ook_signal << snum << "," << z.real() << ",";
 //	snum++;
 } else {
-	z.re = z.im = *buffer++;
+	z = cmplx(*buffer, *buffer);
 }
 #else
-		z.re = z.im = *buffer++;
+	z = cmplx(*buffer, *buffer);
 #endif
+	buffer++;
 
 // Mix it with the audio carrier frequency to create two baseband signals
 // mark and space are separated and processed independently
@@ -631,18 +632,18 @@ if (snum < 2 * filter_length) {
 		n_out = space_filt->run(zspace, &zp_space);
 #if FILTER_DEBUG == 1
 if (snum < 2 * filter_length) {
-	ook_signal << zmark.mag() <<"\n";
+	ook_signal << abs(zmark) <<"\n";
 	snum++;
 }
 #endif
 		for (int i = 0; i < n_out; i++) {
 
-			mark_mag = zp_mark[i].mag();
+			mark_mag = abs(zp_mark[i]);
 			mark_env = decayavg (mark_env, mark_mag,
 						(mark_mag > mark_env) ? symbollen / 4 : symbollen * 16);
 			mark_noise = decayavg (mark_noise, mark_mag,
 						(mark_mag < mark_noise) ? symbollen / 4 : symbollen * 48);
-			space_mag = zp_space[i].mag();
+			space_mag = abs(zp_space[i]);
 			space_env = decayavg (space_env, space_mag,
 						(space_mag > space_env) ? symbollen / 4 : symbollen * 16);
 			space_noise = decayavg (space_noise, space_mag,
@@ -724,21 +725,27 @@ if (mnum < 2 * filter_length)
 //----------------------------------------------------------------------
 
 // get the baseband-signal and...
-				xy.re = zp_mark[i].re * cos(xy_phase) + zp_mark[i].im * sin(xy_phase);
-				xy.im = zp_space[i].re * cos(xy_phase) + zp_space[i].im * sin(xy_phase);
+				xy = cmplx(
+						zp_mark[i].real() * cos(xy_phase) + zp_mark[i].imag() * sin(xy_phase),
+						zp_space[i].real() * cos(xy_phase) + zp_space[i].imag() * sin(xy_phase) );
 
 // if mark-tone has a higher magnitude than the space-tone,
 // further reduce the scope's space-amplitude and vice versa
 // this makes the scope looking a little bit nicer, too...
 // aka: less noisy...
-				if( zp_mark[i].mag() > zp_space[i].mag() ) {
-					xy.im *= zp_space[i].mag()/zp_mark[i].mag();
+				if( abs(zp_mark[i]) > abs(zp_space[i]) ) {
+// note ox x complex lib does not support xy.real(double) or xy.imag(double)
+					xy = cmplx( xy.real(),
+								xy.imag() * abs(zp_space[i])/abs(zp_mark[i]) );
+//					xy.imag() *= abs(zp_space[i])/abs(zp_mark[i]);
 				} else {
-					xy.re /= zp_space[i].mag()/zp_mark[i].mag();
+					xy = cmplx( xy.real() / ( abs(zp_space[i])/abs(zp_mark[i]) ),
+								xy.imag() );
+//					xy.real() /= abs(zp_space[i])/abs(zp_mark[i]);
 				}
 
 // now normalize the scope
-				double const norm = 1.3*(zp_mark [i].mag() + zp_space[i].mag());
+				double const norm = 1.3*(abs(zp_mark [i]) + abs(zp_space[i]));
 				xy /= norm;
 
 			} else {
@@ -747,9 +754,9 @@ if (mnum < 2 * filter_length)
 //----------------------------------------------------------------------
 // get magnitude of the baseband-signal
 				if (bit)
-					xy = complex( mark_mag * cos(xy_phase), space_noise * sin(xy_phase) / 2.0);
+					xy = cmplx( mark_mag * cos(xy_phase), space_noise * sin(xy_phase) / 2.0);
 				else
-					xy = complex( mark_noise * cos(xy_phase) / 2.0, space_mag * sin(xy_phase));
+					xy = cmplx( mark_noise * cos(xy_phase) / 2.0, space_mag * sin(xy_phase));
 // now normalize the scope
 				double const norm = (mark_env + space_env);
 				xy /= norm;
@@ -758,7 +765,7 @@ if (mnum < 2 * filter_length)
 // Rotate the scope x-y iaw frequency error.  Old scopes were not capable
 // of this, but it should be very handy, so... who cares of realism anyways?
 			double const rotate = 8 * TWOPI * freqerr / rtty_shift;
-			xy = xy * complex(cos(rotate), sin(rotate));
+			xy = xy * cmplx(cos(rotate), sin(rotate));
 
 			QI[inp_ptr] = xy;
 
@@ -794,8 +801,8 @@ if (mnum < 2 * filter_length)
 				if (mp1 < 0) mp1 += MAXPIPE;
 				double ferr = (TWOPI * samplerate / rtty_baud) *
 						(!reverse ?
-							(mark_history[mp1] % mark_history[mp0]).arg() :
-							(space_history[mp1] % space_history[mp0]).arg());
+							arg(conj(mark_history[mp1]) * mark_history[mp0]) :
+							arg(conj(space_history[mp1]) * space_history[mp0]));
 				if (fabs(ferr) > rtty_baud / 2) ferr = 0;
 				freqerr = decayavg ( freqerr, ferr / 8,
 					progdefaults.rtty_afcspeed == 0 ? 8 :
@@ -811,7 +818,8 @@ if (mnum < 2 * filter_length)
 				if (clear_zdata) {
 					clear_zdata = false;
 					Clear_syncscope();
-					for (int i = 0; i < MAXPIPE; i++) QI[i].re = QI[i].im = 0.0;
+					for (int i = 0; i < MAXPIPE; i++) 
+						QI[i] = cmplx(0.0, 0.0);
 				}
 			}
 			if (!--showxy) {
@@ -827,8 +835,7 @@ if (mnum < 2 * filter_length)
 // RTTY transmit
 //=====================================================================
 //double freq1;
-double minamp = 100;
-double maxamp = -100;
+double maxamp = 0;
 
 double rtty::nco(double freq)
 {
@@ -855,6 +862,7 @@ double rtty::FSKnco()
 
 void rtty::send_symbol(int symbol, int len)
 {
+	acc_symbols += len;
 #if 0
 	double freq;
 
@@ -879,20 +887,39 @@ void rtty::send_symbol(int symbol, int len)
 	double const freq1 = get_txfreq_woffset() + shift / 2.0;
 	double const freq2 = get_txfreq_woffset() - shift / 2.0;
 	double mark = 0, space = 0;
+	double signal = 0;
 
 	if (reverse)
 		symbol = !symbol;
 
+	if (maxamp == 0) {
+		int sym = 0;
+		for (int j = 0; j < 100; j++) {
+			if (sym) sym = 0;
+			else sym = 1;
+			for( int i = 0; i < 3*len; ++i ) {
+				mark  = m_SymShaper1->Update( sym) * m_Osc1->Update( freq1 );
+				space = m_SymShaper2->Update(!sym) * m_Osc2->Update( freq2 );
+				signal = mark + space;
+				if (maxamp < fabs(signal)) maxamp = fabs(signal);
+			}
+		}
+	}
+
 	for( int i = 0; i < len; ++i ) {
 		mark  = m_SymShaper1->Update( symbol) * m_Osc1->Update( freq1 );
 		space = m_SymShaper2->Update(!symbol) * m_Osc2->Update( freq2 );
-		outbuf[i] = mark + space;
+
+		signal = mark + space;
+		if (maxamp < fabs(signal)) {
+			maxamp = fabs(signal);
+		}
+		outbuf[i] = maxamp ? (0.99 * signal / maxamp) : 0.0;
+
 		if (symbol)
 			FSKbuf[i] = FSKnco();
 		else
 			FSKbuf[i] = 0.0 * FSKnco();
-		if (minamp > outbuf[i]) minamp = outbuf[i];
-		if (maxamp < outbuf[i]) maxamp = outbuf[i];
 	}
 #endif
 
@@ -924,7 +951,7 @@ void rtty::send_stop()
 
 	double const freq1 = get_txfreq_woffset() + shift / 2.0;
 	double const freq2 = get_txfreq_woffset() - shift / 2.0;
-	double mark = 0, space = 0;
+	double mark = 0, space = 0, signal = 0;
 
 	bool symbol = true;
 
@@ -934,7 +961,11 @@ void rtty::send_stop()
 	for( int i = 0; i < stoplen; ++i ) {
 		mark  = m_SymShaper1->Update( symbol)*m_Osc1->Update( freq1 );
 		space = m_SymShaper2->Update(!symbol)*m_Osc2->Update( freq2 );
-		outbuf[i] = mark + space;
+
+		signal = mark + space;
+		if (maxamp < fabs(signal)) maxamp = fabs(signal);
+		outbuf[i] = maxamp ? (0.99 * signal / maxamp) : 0.0;
+
 		if (reverse)
 			FSKbuf[i] = 0.0 * FSKnco();
 		else
@@ -953,12 +984,16 @@ void rtty::flush_stream()
 {
 	double const freq1 = get_txfreq_woffset() + shift / 2.0;
 	double const freq2 = get_txfreq_woffset() - shift / 2.0;
-	double mark = 0, space = 0;
+	double mark = 0, space = 0, signal = 0;
 
 	for( int i = 0; i < symbollen * 6; ++i ) {
 		mark  = m_SymShaper1->Update(0)*m_Osc1->Update( freq1 );
 		space = m_SymShaper2->Update(0)*m_Osc2->Update( freq2 );
-		outbuf[i] = mark + space;
+
+		signal = mark + space;
+		if (maxamp < fabs(signal)) maxamp = fabs(signal);
+		outbuf[i] = maxamp ? (0.99 * signal / maxamp) : 0.0;
+
 		FSKbuf[i] = 0.0;
 	}
 
@@ -1062,7 +1097,16 @@ int rtty::tx_process()
 
 // if NOT Baudot
 	if (nbits != 5) {
+///
+		acc_symbols = 0;
 		send_char(c);
+		xmt_samples = char_samples = acc_symbols;
+
+//		printf("%5s %d samples, overhead %d, %f sec's\n",
+//			ascii3[c & 0xff],
+//			char_samples,
+//			ovhd_samples,
+//			1.0 * char_samples / samplerate);
 		return 0;
 	}
 
@@ -1120,8 +1164,16 @@ int rtty::tx_process()
 			txmode = FIGURES;
 		}
 	}
-
+///
+	acc_symbols = 0;
 	send_char(c & 0x1F);
+	xmt_samples = char_samples = acc_symbols;
+
+//	printf("%5s %d samples, overhead %d, %f sec's\n",
+//		ascii3[c & 0xff],
+//		char_samples,
+//		ovhd_samples,
+//		1.0 * char_samples / samplerate);
 
 	return 0;
 }
@@ -1262,6 +1314,7 @@ void SymbolShaper::Preset(double baud, double sr)
 
 // reset internal states
     reset();
+    maxamp = 0;
 }
 
 double SymbolShaper::Update( bool state )
