@@ -6,28 +6,31 @@
 //
 // This modem code owes much to the efforts of Joe Veldhuis, N8FQ
 //
-// This file is part of fldigi.  Adapted from code contained in gmfsk source code
-// distribution.
+// Adapted from code contained in gmfsk source code distribution.
 //  gmfsk Copyright (C) 2001, 2002, 2003
 //  Tomi Manninen (oh2bns@sral.fi)
 //  Copyright (C) 2004
 //  Lawrence Glaister (ve7it@shaw.ca)
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// Fldigi is free software: you can redistribute it and/or modify
+// This file is part of fldigi
+//
+// fldigi is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// Fldigi is distributed in the hope that it will be useful,
+// fldigi is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
-
 #include <config.h>
 
 #include <stdlib.h>
@@ -208,13 +211,12 @@ feld::feld(trx_mode m)
 
 // rx section
 
-complex feld::mixer(complex in)
+cmplx feld::mixer(cmplx in)
 {
 
-	complex z;
+	cmplx z;
 
-	z.re = cos(rxphacc);
-	z.im = sin(rxphacc);
+	z = cmplx( cos(rxphacc), sin(rxphacc) );
 
 	z = z * in;
 
@@ -228,16 +230,16 @@ complex feld::mixer(complex in)
 	return z;
 }
 
-void feld::FSKHELL_rx(complex z)
+void feld::FSKHELL_rx(cmplx z)
 {
 	double f;
 	double vid;
 	double avg;
 
-	f = (prev % z).arg() * phi2freq;
+	f = arg(conj(prev) * z) * phi2freq;
 	prev = z;
 	f = bbfilt->run(f);
-	avg = average->run(z.mag());
+	avg = average->run(abs(z));
 
 	rxcounter += downsampleinc;
 	if (rxcounter < 1.0)
@@ -274,11 +276,11 @@ void feld::FSKHELL_rx(complex z)
 	}
 }
 
-void feld::rx(complex z)
+void feld::rx(cmplx z)
 {
 	double x, avg;
 
-	x = z.mag();
+	x = abs(z);
 	if (x > peakval) peakval = x;
 	avg = average->run(x);
 
@@ -325,7 +327,7 @@ void feld::rx(complex z)
 int feld::rx_process(const double *buf, int len)
 {
 
-	complex z, *zp;
+	cmplx z, *zp;
 	int i, n;
 
 	halfwidth = progdefaults.HellRcvWidth;
@@ -364,7 +366,8 @@ int feld::rx_process(const double *buf, int len)
 
 	while (len-- > 0) {
 		/* create analytic signal... */
-		z.re = z.im = *buf++;
+		z = cmplx( *buf, *buf );
+		buf++;
 
 		hilbert->run(z, z);
 
