@@ -1,23 +1,24 @@
 // ----------------------------------------------------------------------------
 // flarq.cxx - Fast Light ARQ Application
 //
-// Copyright (C) 2007-2009
-//		Dave Freese, W1HKJ
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
 //
-// This file is part of fldigi.
+// This file is part of fldigi
 //
-// Fldigi is free software: you can redistribute it and/or modify
+// fldigi is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// Fldigi is distributed in the hope that it will be useful,
+// fldigi is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -55,17 +56,10 @@
 
 #ifdef __MINGW32__
 #	include "compat.h"
-#	if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR < 3
-#		define dirent fl_dirent_no_thanks
-#		undef dirent
-#		include <dirent.h>
-#	else
-#		include <dirent.h>
-#	endif
-#else
-#	include <dirent.h>
 #endif
 
+#include <dirent.h>
+
 #include "fileselect.h"
 
 #include "socket.h"
