@@ -106,9 +106,10 @@ public:
 
 	void		clear(void);
 	void		clear_sent(void);
-	unsigned int			nextChar(void);
+	int			nextChar(void);
 	bool		eot(void);
 	void		add_text(std::string s);
+	void		pause() { PauseBreak = true; }
 
 	void		setFont(Fl_Font f, int attr = NATTR);
 
@@ -117,6 +118,7 @@ protected:
 	       TX_MENU_CUT, TX_MENU_COPY, TX_MENU_PASTE, TX_MENU_CLEAR, TX_MENU_READ,
 	       TX_MENU_WRAP
 	};
+	int		handle_key_shortcuts(int key);
 	int		handle_key(int key);
 	int		handle_key_macro(int key);
 	int		handle_dnd_drag(int pos);
