@@ -23,6 +23,8 @@
 #ifndef _DEBUG_H_
 #define _DEBUG_H_
 
+#define DEBUG_PSKMAIL 1
+
 #include "util.h"
 
 class debug
@@ -84,6 +86,9 @@ unused__ static uint32_t log_source_ = debug::LOG_OTHER;
 
 #define LOG_SET_SOURCE(source__) log_source_ = source__
 
+extern bool	debug_pskmail;
+extern bool	debug_audio;
+
 #endif // _DEBUG_H_
 
 // Local Variables:
