@@ -169,7 +169,7 @@ extern void set_scope(double *data, int len, bool autoscale = true);
 extern void set_phase(double phase, double quality, bool highlight);
 extern void set_rtty(double, double, double);
 extern void set_video(double *, int, bool = true);
-extern void set_zdata(complex *, int);
+extern void set_zdata(cmplx *, int);
 
 extern void set_scope_xaxis_1(double y1);
 extern void set_scope_xaxis_2(double y2);
@@ -319,8 +319,9 @@ extern void open_recv_folder(const char *fname);
 extern void reset_mnuPlayback();
 
 // character set
-extern void cb_charset_menu(Fl_Widget *, void *charset);
-extern void populate_charset_menu(void);
+extern void set_charset_listbox(Fl_Widget *, void *charset);
+extern void cb_listbox_charset(Fl_Widget *, void *);
+extern void populate_charset_listbox(void);
 extern void set_default_charset(void);
 
 // set notch parameter on flrig
