@@ -85,8 +85,10 @@ enum {
 	MODE_MFSK31,
 	MODE_MFSK64,
 	MODE_MFSK128,
+	MODE_MFSK64L,
+	MODE_MFSK128L,
 	MODE_MFSK_FIRST = MODE_MFSK8,
-	MODE_MFSK_LAST = MODE_MFSK128,
+	MODE_MFSK_LAST = MODE_MFSK128L,
 
 	MODE_WEFAX_576,
 	MODE_WEFAX_288,
