@@ -1,3 +1,23 @@
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
+//
+// This file is part of fldigi
+//
+// fldigi is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
+// fldigi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
+
 #ifndef MAIN_H_
 #define MAIN_H_
 
@@ -81,6 +101,7 @@ extern void			WriteARQ(unsigned char);
 extern void			checkTLF();
 
 void check_nbems_dirs(void);
+void check_data_dir(void);
 extern bool nbems_dirs_checked;
 
 // This inits or reinits everything related to KML: Reloads params etc...
@@ -91,4 +112,7 @@ extern void exit_process();
 
 int directory_is_created( const char * strdir );
 
+// autostart an external program
+extern void start_process(std::string executable);
+
 #endif
