@@ -1,4 +1,22 @@
 // ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
+//
+// This file is part of fldigi
+//
+// fldigi is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
+// fldigi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #ifndef	_MODEM_H
 #define	_MODEM_H
@@ -11,6 +29,7 @@
 #include "digiscope.h"
 #include "globals.h"
 #include "morse.h"
+#include "ascii.h"
 
 #define	OUTBUFSIZE	16384
 // Constants for signal searching & s/n threshold
@@ -23,6 +42,9 @@ public:
 	static double	frequency;
 	static double	tx_frequency;
 	static bool	freqlock;
+	static unsigned long tx_sample_count;
+	static unsigned int tx_sample_rate;
+	static bool XMLRPC_CPS_TEST;
 protected:
 	cMorse	morse;
 	trx_mode mode;
@@ -121,6 +143,8 @@ public:
 	void		videoText();
 	void		pretone();
 
+	virtual void		send_image(std::string) {}
+
 	void		set_stopflag(bool b) { stopflag = b;};
 	bool		get_stopflag() const { return stopflag; };
 
@@ -185,6 +209,20 @@ private:
 
 protected:
 	virtual void s2nreport(void);
+
+// JD & DF for multiple carriers
+public:
+	int  numcarriers; //Number of parallel carriers for M CAR PSK and PSKR and QPSKR
+	int  symbols; //JD for multiple carriers
+	int  acc_symbols;
+	int  char_symbols;
+	int  xmt_symbols;
+	int  ovhd_symbols;
+	int  acc_samples;
+	int  char_samples;
+	int  xmt_samples;
+	int  ovhd_samples;
+
 };
 
 extern modem *null_modem;
@@ -201,6 +239,8 @@ extern modem *mfsk22_modem;
 extern modem *mfsk31_modem;
 extern modem *mfsk64_modem;
 extern modem *mfsk128_modem;
+extern modem *mfsk64l_modem;
+extern modem *mfsk128l_modem;
 
 extern modem *wefax576_modem;
 extern modem *wefax288_modem;
