@@ -59,12 +59,11 @@ private:
 	bool			_qpsk;
 	bool			_pskr;
 	double			phaseacc[MAX_CARRIERS];
-	complex			prevsymbol[MAX_CARRIERS];
+	cmplx			prevsymbol[MAX_CARRIERS];
 	unsigned int		shreg;
 	//FEC: 2nd stream
 	unsigned int		shreg2;
-	int			numinterleavers; //interleaver size (speed dependant)
-	double 			numcarriers; //Number of parallel carriers for M CAR PSK and PSKR and QPSKR
+	int					numinterleavers; //interleaver size (speed dependant)
 	double 			inter_carrier; // Frequency gap betweeb carriers
 
 // rx variables & functions
@@ -112,13 +111,13 @@ private:
 
 	int 			dcd;
 	int				dcdbits;
-	complex			quality;
+	cmplx			quality;
 	int				acquire;
 
 	viewpsk*		pskviewer;
 	pskeval*		evalpsk;
 
-	void			rx_symbol(complex symbol, int car);
+	void			rx_symbol(cmplx symbol, int car);
 	void 			rx_bit(int bit);
 	void 			rx_bit2(int bit);
 	void			rx_qpsk(int bits);
@@ -139,13 +138,13 @@ private:
 	double			sc_bw; // single carrier bandwidth
 
 	
-//	complex thirdorder;
+//	cmplx thirdorder;
 // tx variables & functions
-	int			accumulated_bits; //JD for multiple carriers
-	int			txsymbols[MAX_CARRIERS];
+	int				txsymbols[MAX_CARRIERS];
 
 	double			*tx_shape;
 	int 			preamble;
+	void			tx_carriers();
 	void 			tx_symbol(int sym);
 	void			tx_bit(int bit);
 	void			tx_char(unsigned char c);
@@ -159,7 +158,7 @@ private:
 
 	void			initSN_IMD();
 	void			resetSN_IMD();
-	void			calcSN_IMD(complex z);
+	void			calcSN_IMD(cmplx z);
 	//PSKR modes - for Tx interleaver priming
 	void 			clearbits();
 
@@ -177,6 +176,7 @@ public:
 	int tx_process();
 	void searchDown();
 	void searchUp();
+
 };
 
 #endif
