@@ -3,7 +3,7 @@
 //
 // Copyright (C) 2012
 //		Dave Freese, W1HKJ
-//		Stefan Fendt, DO2SMF
+//		Stefan Fendt, DL1SMF
 //
 // This file is part of fldigi.
 //
@@ -163,8 +163,8 @@ private:
 	double *dsppipe;
 	int pipeptr;
 
-	complex mark_history[MAXPIPE];
-	complex space_history[MAXPIPE];
+	cmplx mark_history[MAXPIPE];
+	cmplx space_history[MAXPIPE];
 
 	RTTY_RX_STATE rxstate;
 
@@ -175,15 +175,15 @@ private:
 	double shift_offset; // 1/2 rtty_shift
 
 	double prevsymbol;
-	complex prevsmpl;
+	cmplx prevsmpl;
 
 	double xy_phase;
 	double rotate;
 
-	complex QI[MAXPIPE];
+	cmplx QI[MAXPIPE];
 	int inp_ptr;
 
-	complex xy;
+	cmplx xy;
 
 	bool   clear_zdata;
 	double sigpwr;
@@ -210,7 +210,7 @@ private:
 	void Update_syncscope();
 
 	double IF_freq;
-	inline complex mixer(double &phase, double f, complex in);
+	inline cmplx mixer(double &phase, double f, cmplx in);
 
 	unsigned char Bit_reverse(unsigned char in, int n);
 	int decode_char();
