@@ -1,3 +1,23 @@
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
+//
+// This file is part of fldigi
+//
+// fldigi is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
+// fldigi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
+
 #include <FL/Fl.H>
 #include <FL/filename.H>
 #include <FL/fl_ask.H>
@@ -61,8 +81,13 @@ FIELD fields[] = {
 	{IOTA,           "IOTA",         &btnSelectIOTA},      // Islands on the air
 	{ITUZ,           "ITUZ",         &btnSelectITUZ},      // ITU zone
 	{CONT,           "CONT",         &btnSelectCONT},      // contacted stations continent
+
 	{MYXCHG,         "MYXCHG",       &btnSelectMyXchg},    // contest exchange sent
 	{XCHG1,          "XCHG1",        &btnSelectXchgIn},    // contest exchange #1 / free1 in xlog
+
+	{MYXCHG,         "STX_STRING",   &btnSelectMyXchg},    // contest exchange sent
+	{XCHG1,          "SRX_STRING",   &btnSelectXchgIn},    // contest exchange #1 / free1 in xlog
+
 	{SRX,            "SRX",          &btnSelectSerialIN},  // received serial number for a contest QSO
 	{STX,            "STX",          &btnSelectSerialOUT}, // QSO transmitted serial number
 	{TX_PWR,         "TX_PWR",       &btnSelectTX_pwr},    // power transmitted by this station
@@ -335,6 +360,8 @@ int cAdifIO::writeFile (const char *fname, cQsoDb *db)
 		if (rec->getField(EXPORT)[0] == 'E') {
 			int j = 0;
 			while (fields[j].type != NUMFIELDS) {
+				if (strcmp(fields[j].name,"MYXCHG") == 0) { j++; continue; }
+				if (strcmp(fields[j].name,"XCHG1") == 0) { j++; continue; }
 				if (fields[j].btn != NULL)
 					if ((*fields[j].btn)->value()) {
 					sFld = rec->getField(fields[j].type);
@@ -478,6 +505,8 @@ void cAdifIO::do_writelog()
 		record.clear();
 		int j = 0;
 		while (fields[j].type != NUMFIELDS) {
+			if (strcmp(fields[j].name,"MYXCHG") == 0) { j++; continue; }
+			if (strcmp(fields[j].name,"XCHG1") == 0) { j++; continue; }
 			sFld = rec->getField(fields[j].type);
 			if (!sFld.empty()) {
 				snprintf(recfield, sizeof(recfield), adifmt,
