@@ -26,6 +26,7 @@
 #include <fstream>
 #include <string>
 
+#include "gettext.h"
 #include "speak.h"
 #include "main.h"
 #include "status.h"
@@ -38,19 +39,19 @@
 
 using namespace std;
 
-const char *txtTalkInfo = "\
+const char *txtTalkInfo = _("\
 Save all received text, one character at a time to the following file:\n\n\
     fldigi.files\\talk\\textout.txt (Windows)\n\
-    ~/.fldigi/talk/textout.txt (Linux, OS X, Free BSD)";
+    ~/.fldigi/talk/textout.txt (Linux, OS X, Free BSD)");
 
 string speakfname = "";
 ofstream speakout;
 string speakbuffer = "";
 
 #ifndef __WIN32__
-void open_talker()
-{
-}
+void open_talker() {}
+void close_talker() {}
+void toggle_talker() {}
 #endif
 
 #ifdef __WIN32__
@@ -68,13 +69,14 @@ void open_talker()
 		talker_tcpip = new Socket(Address(talker_address.c_str(), talker_port.c_str()));
 		talker_tcpip->set_timeout(0.01);
 		talker_tcpip->connect();
-		btnConnectTalker->labelcolor(FL_FOREGROUND_COLOR);
-		btnConnectTalker->redraw_label();
+		btnConnectTalker->value(1);
+		btnConnectTalker->redraw();
+		can_talk = true;
 	}
 	catch (const SocketException& e) {
 		LOG_INFO("Talker Server not available");
-		btnConnectTalker->labelcolor(FL_RED);
-		btnConnectTalker->redraw_label();
+		btnConnectTalker->value(0);
+		btnConnectTalker->redraw();
 		can_talk = false;
 	}
 }
@@ -82,6 +84,17 @@ void open_talker()
 void close_talker()
 {
 	talker_tcpip->close();
+	btnConnectTalker->value(0);
+	btnConnectTalker->redraw();
+	can_talk = false;
+}
+
+void toggle_talker()
+{
+	if (can_talk)
+		close_talker();
+	else
+		open_talker();
 }
 
 void speak(int c)
