@@ -158,6 +158,7 @@ void loadBrowser(Fl_Widget *widget) {
 
 	w->add(LINE_SEP);
 	w->add(_("<FILE:>\tinsert text file"));
+	w->add(_("<IMAGE:>\tinsert MFSK image"));
 	w->add(LINE_SEP);
 
 	w->add(_("<PAUSE>\tpause transmit"));
@@ -166,7 +167,7 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<TUNE:NN>\ttune signal for NN sec"));
 	w->add(_("<WAIT:NN>\tdelay xmt for NN sec"));
 	w->add(_("<REPEAT>\trepeat macro continuously"));
-	w->add(_("<SKED:hhmm[:YYYYDDMM]>\tschedule execution"));
+	w->add(_("<SKED:hhmm[ss][:YYYYMMDD]>\tschedule execution"));
 
 	w->add(LINE_SEP);
 	w->add(_("<TXATTEN:nn.n>\t set xmt attenuator"));
@@ -201,6 +202,16 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(LINE_SEP);
 	w->add(_("<COMMENT:text>\tuntransmitted comment"));
 
+	w->add(LINE_SEP);
+	w->add(_("<CPS_TEST>\tmodem timing test internal string"));
+	w->add(_("<CPS_FILE:>\tmodem timing test, spec' file"));
+	w->add(_("<CPS_STRING:s>\tmodem timing test, string 's'"));
+
+	w->add(LINE_SEP);
+	w->add(_("<WAV_TEST>\tWAV file; internal string"));
+	w->add(_("<WAV_FILE:>\tWAV file; spec' file"));
+	w->add(_("<WAV_STRING:s>\tWAV file; string 's'"));
+
 	w->add(LINE_SEP);
 	assert(MODE_CONTESTIA < MODE_OLIVIA);
 	char s[256];
@@ -320,6 +331,21 @@ void cbInsertMacro(Fl_Widget *, void *)
 			text.insert(6, p);
 		} else
 			text = "";
+	} else if ((text == "<CPS_FILE:>") || (text == "<WAV_FILE:>")) {
+		string filters = "Text\t*." "txt";
+		const char* p = FSEL::select(_("Test text file"), filters.c_str(),
+					 "text." "txt");
+		if (p) {
+			text.insert(10, p);
+		} else
+			text = "";
+	} else if (text == "<IMAGE:>") {
+		string filters = "Text\t*." "txt";
+		const char *p = FSEL::select(_("MFSK image file"), "*.{png,jpg,bmp}\t*", "");
+		if (p) {
+			text.insert(7, p);
+		} else
+			text = "";
 	} else if (text == "<MACROS:>") {
 		string filters = "Macrost\t*." "mdf";
 		const char* p = FSEL::select(_("Change to Macro file"), filters.c_str(),
