@@ -25,6 +25,7 @@
 // ----------------------------------------------------------------------------
 
 #include <config.h>
+#include <sys/time.h>
 
 #include "macros.h"
 
@@ -51,6 +52,7 @@
 #include "icons.h"
 #include "weather.h"
 #include "utf8file_io.h"
+#include "xmlrpc.h"
 
 #include <FL/Fl.H>
 #include <FL/filename.H>
@@ -79,7 +81,6 @@ void pushcmd(CMDS cmd)
 	LOG_INFO("%s, # = %d", cmd.cmd.c_str(), (int)cmds.size());
 	cmds.push(cmd);
 }
-//#define pushcmd(a) cmds.push((a))
 
 // these variables are referenced outside of this file
 MACROTEXT macros;
@@ -133,6 +134,343 @@ static size_t mystrftime( char *s, size_t max, const char *fmt, const struct tm
 	return strftime(s, max, fmt, tm);
 }
 
+static string CPSstring = "\
+=============================================\n\
+       ABCDEFGHIJKLMN OPQRSTUVWXYZ\n\
+       abcdefghijklmn opqrstuvwxyz\n\
+       0123456789       9876543210\n\
+      !@#$%&*()_+-=[]{}\\|;:'\",.<>/?\n\
+=============================================\n\
+\n\
+          The Jaberwocky\n\
+\n\
+'Twas brillig, and the slithy toves\n\
+Did gyre and gimble in the wabe;\n\
+All mimsy were the borogoves,\n\
+And the mome raths outgrabe.\n\
+\n\
+\"Beware the Jabberwock, my son!\n\
+The jaws that bite, the claws that catch!\n\
+Beware the Jubjub bird, and shun\n\
+The frumious Bandersnatch!\"\n\
+\n\
+He took his vorpal sword in hand:\n\
+Long time the manxome foe he sought-\n\
+So rested he by the Tumtum tree,\n\
+And stood awhile in thought.\n\
+\n\
+And as in uffish thought he stood,\n\
+The Jabberwock, with eyes of flame,\n\
+Came whiffling through the tulgey wood,\n\
+And burbled as it came!\n\
+\n\
+One, two! One, two! and through and through\n\
+The vorpal blade went snicker-snack!\n\
+He left it dead, and with its head\n\
+He went galumphing back.\n\
+\n\
+\"And hast thou slain the Jabberwock?\n\
+Come to my arms, my beamish boy!\n\
+O frabjous day! Callooh! Callay!\"\n\
+He chortled in his joy.\n\
+\n\
+'Twas brillig, and the slithy toves\n\
+Did gyre and gimble in the wabe;\n\
+All mimsy were the borogoves,\n\
+And the mome raths outgrabe.\n";
+
+bool PERFORM_CPS_TEST = false;
+int  num_cps_chars = 0;
+string testfilename;
+
+void CPS_report(int samples, int prepost)
+{
+	char results[1000];
+	double xmttime = 1.0 * samples / active_modem->get_samplerate();
+	double datatime = 1.0 * (samples - prepost) / active_modem->get_samplerate();
+	num_cps_chars--;
+	snprintf(results, sizeof(results), "\n\
+CPS test\n\
+text:         %s\n\
+mode:         %s\n\
+# chars:      %d\n\
+xmt time:     %f\n\
+data time:    %f\n\
+xmt samples:  %d\n\
+prepost:      %d\n\
+data samples: %d\n\
+sample rate:  %d\n\
+chars/sec:    %f\n\
+~WPM:         %f\n",
+testfilename.c_str(),
+mode_info[active_modem->get_mode()].name,
+num_cps_chars,
+xmttime,
+datatime,
+samples,
+prepost,
+samples - prepost,
+active_modem->get_samplerate(),
+num_cps_chars / datatime,
+10 * num_cps_chars / datatime);
+
+	ReceiveText->add(results, FTextBase::ALTR);
+	LOG_INFO("%s", results);
+	PERFORM_CPS_TEST = false;
+}
+
+static void pCPS_TEST(std::string &s, size_t &i, size_t endbracket)
+{
+	s.clear();
+	trx_mode id = active_modem->get_mode();
+	if ( id == MODE_SSB || id == MODE_WWV || id == MODE_ANALYSIS ||
+		 id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
+		 id == MODE_SITORB || id == MODE_NAVTEX ) {
+		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		return;
+	}
+	testfilename = "internal string";
+
+	stopMacroTimer();
+	active_modem->set_stopflag(false);
+	PERFORM_CPS_TEST = true;
+	trx_transmit();
+
+	int s0 = number_of_samples("");
+	int s1 = 0;
+	int start_stop_samples = 0;
+	int j = 0;
+	for(j = 1; j < 32; j++) {
+		s1 = number_of_samples(string(j, 'e'));
+		if(s1 > s0) break;
+	}
+	start_stop_samples = 2*s0 - s1;
+
+	num_cps_chars = 0;
+	CPS_report(number_of_samples(CPSstring), start_stop_samples);
+	PERFORM_CPS_TEST = false;
+
+}
+
+static void pCPS_FILE(std::string &s, size_t &i, size_t endbracket)
+{
+	trx_mode id = active_modem->get_mode();
+	if ( id == MODE_SSB || id == MODE_WWV || id == MODE_ANALYSIS ||
+		 id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
+		 id == MODE_SITORB || id == MODE_NAVTEX ) {
+		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		s.clear();
+		return;
+	}
+
+	std::string fname = s.substr(i+10, endbracket - i - 10);
+	if (fname.length() > 0 && !within_exec) {
+		FILE *toadd = fopen(fname.c_str(), "r");
+		if (toadd) {
+			std::string buffer;
+			char c = getc(toadd);
+			while (c && !feof(toadd)) {
+				if (c != '\r') buffer += c; // damn MSDOS txt files
+				c = getc(toadd);
+				}
+			s.clear();
+			fclose(toadd);
+			TransmitText->clear();
+			testfilename = fname;
+
+			stopMacroTimer();
+			active_modem->set_stopflag(false);
+			PERFORM_CPS_TEST = true;
+			trx_transmit();
+
+			int s0 = number_of_samples("");
+			int s1 = 0;
+			int start_stop_samples = 0;
+			int j = 0;
+			for(j = 1; j < 32; j++) {
+				s1 = number_of_samples(string(j, 'e'));
+				if(s1 > s0) break;
+			}
+			start_stop_samples = 2*s0 - s1;
+
+			num_cps_chars = 0;
+			CPS_report(number_of_samples(buffer), start_stop_samples);
+			PERFORM_CPS_TEST = false;
+
+		} else {
+			string resp = "Could not locate ";
+			resp.append(fname).append("\n");
+			ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+			LOG_WARN("%s not found", fname.c_str());
+			s.replace(i, endbracket - i + 1, "");
+			PERFORM_CPS_TEST = false;
+		}
+	} else {
+		PERFORM_CPS_TEST = false;
+		s.clear();
+	}
+}
+
+static void pCPS_STRING(std::string &s, size_t &i, size_t endbracket)
+{
+	trx_mode id = active_modem->get_mode();
+	if ( id == MODE_SSB || id == MODE_WWV || id == MODE_ANALYSIS ||
+		 id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
+		 id == MODE_SITORB || id == MODE_NAVTEX ) {
+		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		s.clear();
+		return;
+	}
+
+	std::string buffer = s.substr(i+12, endbracket - i - 12);
+	std::string txtbuf = buffer;
+	s.clear();
+	size_t p = buffer.find("\\n");
+	while (p != string::npos) {
+		buffer.replace(p,2,"\n");
+		p = buffer.find("\\n");
+	}
+	if (buffer.length()) {
+		TransmitText->clear();
+
+		stopMacroTimer();
+		active_modem->set_stopflag(false);
+		PERFORM_CPS_TEST = true;
+		trx_transmit();
+
+		int s0 = number_of_samples("");
+printf("j %d: s %d\n", 0, s0);
+		int s1 = 0;
+		int start_stop_samples = 0;
+		int j = 0;
+		for(j = 1; j < 32; j++) {
+			s1 = number_of_samples(string(j, 'e'));
+printf("j %d: s %d\n", j, s1);
+			if(s1 > s0) break;
+		}
+		start_stop_samples = 2*s0 - s1;
+
+		num_cps_chars = 0;
+		testfilename = txtbuf;
+		CPS_report(number_of_samples(buffer), start_stop_samples);
+		PERFORM_CPS_TEST = false;
+	} else {
+		string resp = "Text not specified";
+		LOG_WARN("%s", resp.c_str());
+		resp.append("\n");
+		ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+		PERFORM_CPS_TEST = false;
+	}
+}
+
+static void pWAV_TEST(std::string &s, size_t &i, size_t endbracket)
+{
+	s.clear();
+	trx_mode id = active_modem->get_mode();
+	if ( id == MODE_SSB || id == MODE_WWV || id == MODE_ANALYSIS ||
+		 id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
+		 id == MODE_SITORB || id == MODE_NAVTEX ) {
+		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		return;
+	}
+	testfilename = "internal string";
+
+	stopMacroTimer();
+	active_modem->set_stopflag(false);
+
+	PERFORM_CPS_TEST = true;
+	trx_transmit();
+	number_of_samples(CPSstring);
+	PERFORM_CPS_TEST = false;
+}
+
+static void pWAV_FILE(std::string &s, size_t &i, size_t endbracket)
+{
+	trx_mode id = active_modem->get_mode();
+	if ( id == MODE_SSB || id == MODE_WWV || id == MODE_ANALYSIS ||
+		 id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
+		 id == MODE_SITORB || id == MODE_NAVTEX ) {
+		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		s.clear();
+		return;
+	}
+
+	std::string fname = s.substr(i+10, endbracket - i - 10);
+	if (fname.length() > 0 && !within_exec) {
+		FILE *toadd = fopen(fname.c_str(), "r");
+		if (toadd) {
+			std::string buffer;
+			char c = getc(toadd);
+			while (c && !feof(toadd)) {
+				if (c != '\r') buffer += c; // damn MSDOS txt files
+				c = getc(toadd);
+				}
+			s.clear();
+			fclose(toadd);
+			TransmitText->clear();
+			testfilename = fname;
+
+			stopMacroTimer();
+			active_modem->set_stopflag(false);
+			PERFORM_CPS_TEST = true;
+			trx_transmit();
+
+			number_of_samples(buffer);
+			PERFORM_CPS_TEST = false;
+
+		} else {
+			string resp = "Could not locate ";
+			resp.append(fname).append("\n");
+			ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+			LOG_WARN("%s not found", fname.c_str());
+			s.replace(i, endbracket - i + 1, "");
+			PERFORM_CPS_TEST = false;
+		}
+	} else {
+		PERFORM_CPS_TEST = false;
+		s.clear();
+	}
+}
+
+static void pWAV_STRING(std::string &s, size_t &i, size_t endbracket)
+{
+	trx_mode id = active_modem->get_mode();
+	if ( id == MODE_SSB || id == MODE_WWV || id == MODE_ANALYSIS ||
+		 id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
+		 id == MODE_SITORB || id == MODE_NAVTEX ) {
+		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		s.clear();
+		return;
+	}
+
+	std::string buffer = s.substr(i+12, endbracket - i - 12);
+	std::string txtbuf = buffer;
+	s.clear();
+	size_t p = buffer.find("\\n");
+	while (p != string::npos) {
+		buffer.replace(p,2,"\n");
+		p = buffer.find("\\n");
+	}
+	if (buffer.length()) {
+		TransmitText->clear();
+
+		stopMacroTimer();
+		active_modem->set_stopflag(false);
+		PERFORM_CPS_TEST = true;
+		trx_transmit();
+
+		testfilename = txtbuf;
+		number_of_samples(buffer);
+		PERFORM_CPS_TEST = false;
+	} else {
+		string resp = "Text not specified";
+		LOG_WARN("%s", resp.c_str());
+		resp.append("\n");
+		ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+		PERFORM_CPS_TEST = false;
+	}
+}
+
 static void pCOMMENT(std::string &s, size_t &i, size_t endbracket)
 {
 	s.replace(i, endbracket - i + 1, "");
@@ -959,7 +1297,7 @@ static void pRIGCAT(std::string &s, size_t &i, size_t endbracket)
 
 	LOG_INFO("cat %s", hexstr(buff).c_str());
 
-	sendCommand(buff, retnbr);
+	sendCommand(buff, retnbr, progdefaults.RigCatWait);
 
 	s.replace(i, endbracket - i + 1, "");
 }
@@ -1122,6 +1460,35 @@ static void pMODEM_compSKED(std::string &s, size_t &i, size_t endbracket)
 	s.erase(i, k-i);
 }
 
+static void doIMAGE(std::string s)
+{
+	if (s.length() > 0) {
+		string fname = s.substr(7);
+		fname.erase(fname.length() - 1);
+		trx_mode active_mode = active_modem->get_mode();
+		if ((active_mode == MODE_MFSK16 ||
+			 active_mode == MODE_MFSK32 ||
+			 active_mode == MODE_MFSK64 ||
+			 active_mode == MODE_MFSK128) &&
+			 active_modem->get_cap() & modem::CAP_IMG) {
+			active_modem->send_image(fname);
+		}
+	}
+	que_ok = true;
+}
+
+static void pQueIMAGE(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	string cmdstr = s.substr(i, endbracket - i + 1);
+	struct CMDS cmd = { cmdstr, doIMAGE };
+	pushcmd(cmd);
+	s.replace(i, endbracket - i + 1, "^!");
+}
+
 #include <float.h>
 #include "re.h"
 
@@ -1215,9 +1582,19 @@ static void pQueMODEM(std::string &s, size_t &i, size_t endbracket)
 		s.replace(i, endbracket - i + 1, "");
 		return;
 	}
-	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doMODEM };
-	pushcmd(cmd);
-	s.replace(i, endbracket - i + 1, "^!");
+	string cmdstr = s.substr(i, endbracket - i + 1);
+	struct CMDS cmd = { cmdstr, doMODEM };
+	if (cmdstr.find("SSB") != string::npos || cmdstr.find("ANALYSIS") != string::npos) {
+		LOG_ERROR("Disallowed: %s", cmdstr.c_str());
+		size_t nextbracket = s.find('<', endbracket);
+		if (nextbracket != string::npos)
+			s.erase(i, nextbracket - i - 1);
+		else
+			s.clear(); 
+	} else {
+		pushcmd(cmd);
+		s.replace(i, endbracket - i + 1, "^!");
+	}
 }
 
 static void pMODEM(std::string &s, size_t &i, size_t endbracket)
@@ -1736,7 +2113,6 @@ static void doFILWID(std::string s)
 	qso_opBW->value(sWID.c_str());
 	cb_qso_opBW();
 	que_ok = true;
-printf("BW %s\n", sWID.c_str());
 }
 
 static void pQueFILWID(std::string &s, size_t &i, size_t endbracket)
@@ -2137,6 +2513,7 @@ static void pSKED(std::string &s, size_t &i, size_t endbracket)
 		exec_time = data.substr(0, p);
 		exec_date = data.substr(p+1);
 	}
+	if (exec_time.length() == 4) exec_time.append("00");
 	timed_exec = true;
 	s.replace(i, endbracket - i + 1, "");
 }
@@ -2188,6 +2565,14 @@ static std::string rxcmds = "<!MOD<!WAI<!GOH<!QSY<!GOF<!RIG<!FIL";
 struct MTAGS { const char *mTAG; void (*fp)(std::string &, size_t&, size_t );};
 
 static const MTAGS mtags[] = {
+{"<CPS_FILE:",	pCPS_FILE},
+{"<CPS_STRING:",pCPS_STRING},
+{"<CPS_TEST",	pCPS_TEST},
+
+{"<WAV_FILE:",	pWAV_FILE},
+{"<WAV_STRING:",pWAV_STRING},
+{"<WAV_TEST",	pWAV_TEST},
+
 {"<COMMENT:",	pCOMMENT},
 {"<CALL>",		pCALL},
 {"<FREQ>",		pFREQ},
@@ -2284,6 +2669,7 @@ static const MTAGS mtags[] = {
 #endif
 {"<WX>",		pWX},
 {"<WX:",		pWX2},
+{"<IMAGE:",		pQueIMAGE},
 {"<!WPM:",		pQueWPM},
 {"<!RISE:",		pQueRISETIME},
 {"<!PRE:",		pQuePRE},
@@ -2697,8 +3083,6 @@ static std::string mtext =
 
 void MACROTEXT::saveMacros(const std::string& fname) {
 
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
-
 	std::string work;
 	std::string output;
 	char temp[200];
@@ -2718,29 +3102,6 @@ void MACROTEXT::saveMacros(const std::string& fname) {
 	}
 	UTF8_writefile(fname.c_str(), output);
 
-#else
-
-	std::string work;
-
-	ofstream mfile(fname.c_str());
-	mfile << mtext;
-	for (int i = 0; i < MAXMACROS; i++) {
-		mfile << "\n//\n// Macro # " << i+1 << "\n";
-		mfile << "/$ " << i << " " << macros.name[i].c_str() << "\n";
-		work = macros.text[i];
-		size_t pos;
-		pos = work.find('\n');
-		while (pos != std::string::npos) {
-			work.insert(pos, "\\n");
-			pos = work.find('\n', pos + 3);
-		}
-		mfile << work.c_str();
-	}
-	mfile << "\n";
-	mfile.close();
-
-#endif
-
 	changed = false;
 }
 
