@@ -404,8 +404,9 @@ void status::loadLastState()
 {
 	Fl_Preferences spref(HomeDir.c_str(), "w1hkj.com", PACKAGE_TARNAME);
 
+	int i;
+	char strbuff[1000];
 	char version[64]; version[sizeof(version)-1] = '\0';
-	char* defbuffer;
 
 	// Skip loading the rest of the status variables if we didn't read a
 	// version name/value pair; or this is not a file that supports dual
@@ -417,10 +418,9 @@ void status::loadLastState()
 	if (!bLastStateRead)
 		return;
 
-	int i;
-
-	spref.get("mode_name", defbuffer, mode_info[MODE_PSK31].sname);
-	mode_name = defbuffer;
+	memset(strbuff, 0, sizeof(strbuff));
+	spref.get("mode_name", strbuff, mode_info[MODE_PSK31].sname, sizeof(strbuff) - 1);
+	mode_name = strbuff;
 	lastmode = MODE_PSK31;
 	for (i = 0; i < NUM_MODES;i++) {
 		if (mode_name == mode_info[i].sname) {
@@ -451,12 +451,14 @@ void status::loadLastState()
 	progdefaults.wfAmpSpan = ampspan;
 	
 	spref.get("noCATfreq", noCATfreq, noCATfreq);
-	spref.get("noCATmode", defbuffer, "USB");
-	noCATmode = defbuffer;
-	free(defbuffer);
-	spref.get("noCATwidth", defbuffer, "3000");
-	noCATwidth = defbuffer;
-	free(defbuffer);
+
+	memset(strbuff, 0, sizeof(strbuff));
+	spref.get("noCATmode", strbuff, "USB", sizeof(strbuff) - 1);
+	noCATmode = strbuff;
+
+	memset(strbuff, 0, sizeof(strbuff));
+	spref.get("noCATwidth", strbuff, "3000", sizeof(strbuff) - 1);
+	noCATwidth = strbuff;
 
 	spref.get("main_x", mainX, mainX);
 	spref.get("main_y", mainY, mainY);
@@ -494,9 +496,9 @@ void status::loadLastState()
 	spref.get("scope_w", scopeW, scopeW);
 	spref.get("scope_h", scopeH, scopeH);
 
-	spref.get("last_macro_file", defbuffer, "macros.mdf");
-	LastMacroFile = defbuffer;
-	free(defbuffer);
+	memset(strbuff, 0, sizeof(strbuff));
+	spref.get("last_macro_file", strbuff, "macros.mdf", sizeof(strbuff) - 1);
+	LastMacroFile = strbuff;
 
 	spref.get("spot_recv", i, spot_recv); spot_recv = i;
 	spref.get("spot_log", i, spot_log); spot_log = i;
@@ -551,12 +553,11 @@ void status::loadLastState()
 	spref.get("uosrx", i, UOSrx); UOSrx = i;
 	spref.get("uostx", i, UOStx); UOStx = i;
 
-	spref.get("browser_search", defbuffer, browser_search.c_str());
-	browser_search = defbuffer;
+	memset(strbuff, 0, sizeof(strbuff));
+	spref.get("browser_search", strbuff, browser_search.c_str(), sizeof(strbuff) - 1);
+	browser_search = strbuff;
 	seek_re.recompile(browser_search.c_str());
 
-	free(defbuffer);
-
 //	spref.get("xml_logbook", i, xml_logbook); xml_logbook = i;
 }
 
@@ -567,19 +568,18 @@ void status::initLastState()
 
 // RTTY
 	if (lastmode == MODE_RTTY ) {
-		if (rtty_shift > 0) {
-			progdefaults.rtty_shift = rtty_shift;
-			selShift->value(rtty_shift);
+		progdefaults.rtty_shift = rtty_shift;
+		selShift->index(progdefaults.rtty_shift + 1);
+		if (rtty_shift == selShift->lsize() - 1) {
 			selCustomShift->deactivate();
 		}
 		else { // Custom shift
-			selShift->value(selShift->size() - 2);
-			selShift->activate();
+			selCustomShift->activate();
 		}
-		selBaud->value(progdefaults.rtty_baud = rtty_baud);
-		selBits->value(progdefaults.rtty_bits = rtty_bits);
-		selParity->value(progdefaults.rtty_parity = rtty_parity);
-		selStopBits->value(progdefaults.rtty_stop = rtty_stop);
+		selBaud->index((progdefaults.rtty_baud = rtty_baud) + 1);
+		selBits->index((progdefaults.rtty_bits = rtty_bits) + 1);
+		selParity->index((progdefaults.rtty_parity = rtty_parity) + 1);
+		selStopBits->index((progdefaults.rtty_stop = rtty_stop) + 1);
 		btnCRCRLF->value(progdefaults.rtty_crcrlf = rtty_crcrlf);
 		btnAUTOCRLF->value(progdefaults.rtty_autocrlf = rtty_autocrlf);
 		cntrAUTOCRLF->value(progdefaults.rtty_autocount = rtty_autocount);
@@ -587,7 +587,7 @@ void status::initLastState()
 		chkUOSrx->value(progdefaults.UOSrx = UOSrx);
 		chkUOStx->value(progdefaults.UOStx = UOStx);
 //		chkXagc->value(progdefaults.Xagc = Xagc);
-		mnuRTTYAFCSpeed->value(progdefaults.rtty_afcspeed = rtty_afcspeed);
+		i_listbox_rtty_afc_speed->index(progdefaults.rtty_afcspeed = rtty_afcspeed);
 		btnPreferXhairScope->value(progdefaults.PreferXhairScope = PreferXhairScope);
 
 		if (mvsquelch) {
@@ -613,8 +613,8 @@ void status::initLastState()
 
 // OLIVIA
 	if (lastmode == MODE_OLIVIA) {
-		mnuOlivia_Tones->value(progdefaults.oliviatones = oliviatones);
-		mnuOlivia_Bandwidth->value(progdefaults.oliviabw = oliviabw);
+		i_listbox_olivia_tones->index(progdefaults.oliviatones = oliviatones);
+		i_listbox_olivia_bandwidth->index(progdefaults.oliviabw = oliviabw);
 		cntOlivia_smargin->value(progdefaults.oliviasmargin = oliviamargin);
 		cntOlivia_sinteg->value(progdefaults.oliviasinteg = oliviainteg);
 		btnOlivia_8bit->value(progdefaults.olivia8bit = olivia8bit);
@@ -622,8 +622,8 @@ void status::initLastState()
 
 // CONTESTIA
 	if (lastmode == MODE_CONTESTIA) {
-		mnuContestia_Tones->value(progdefaults.contestiatones = contestiatones);
-		mnuContestia_Bandwidth->value(progdefaults.contestiabw = contestiabw);
+		i_listbox_contestia_tones->index(progdefaults.contestiatones = contestiatones);
+		i_listbox_contestia_bandwidth->index(progdefaults.contestiabw = contestiabw);
 		cntContestia_smargin->value(progdefaults.contestiasmargin = contestiamargin);
 		cntContestia_sinteg->value(progdefaults.contestiasinteg = contestiainteg);
 		btnContestia_8bit->value(progdefaults.contestia8bit = contestia8bit);
@@ -688,8 +688,8 @@ void status::initLastState()
 
 	ReceiveText->set_quick_entry(quick_entry);
 	ReceiveText->set_scroll_hints(rx_scroll_hints);
-	ReceiveText->set_word_wrap(rx_word_wrap);
-	TransmitText->set_word_wrap(tx_word_wrap);
+	ReceiveText->set_word_wrap(rx_word_wrap, true);
+	TransmitText->set_word_wrap(tx_word_wrap, true);
 
 //	set_server_label(xml_logbook);
 
