@@ -64,6 +64,7 @@ void parseLSBMODES(size_t &);
 void parseDISCARD(size_t &);
 
 void parseWRITE_DELAY(size_t &);
+void parseINIT_DELAY(size_t &);
 void parsePOST_WRITE_DELAY(size_t &);
 void parseRETRIES(size_t &);
 void parseTIMEOUT(size_t &);
@@ -134,6 +135,7 @@ TAGS rigdeftags[] = {
 	{"<PROGRAMMER", parseDISCARD},
 	{"<STATUS",		parseDISCARD},
 	{"<WRITE_DELAY", parseWRITE_DELAY},
+	{"<INIT_DELAY", parseINIT_DELAY},
 	{"<POST_WRITE_DELAY", parsePOST_WRITE_DELAY},
 	{"<RETRIES", parseRETRIES},
 	{"<TIMEOUT", parseTIMEOUT},
@@ -545,6 +547,13 @@ void parseWRITE_DELAY(size_t &p0){
 	p0 = pend;
 }
 
+void parseINIT_DELAY(size_t &p0){
+	int val = getInt(p0);
+	xmlrig.init_delay = val;
+	size_t pend = tagEnd(p0);
+	p0 = pend;
+}
+
 void parsePOST_WRITE_DELAY(size_t &p0){
 	int val = getInt(p0);
 	xmlrig.post_write_delay = val;
