@@ -1,10 +1,35 @@
+// ----------------------------------------------------------------------------
+// Copyright (C) 2014
+//              David Freese, W1HKJ
+//
+// This file is part of fldigi
+//
+// fldigi is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
+// fldigi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
+
 // Syntax: ELEM_(rsid_code, rsid_tag, fldigi_mode)
 // fldigi_mode is NUM_MODES if mode is not available in fldigi,
 // otherwise one of the tags defined in globals.h.
 // rsid_tag is stringified and may be shown to the user.
+/*
+        ELEM_(263, ESCAPE, NUM_MODES)                   \
+*/
 #undef ELEM_
 #define RSID_LIST                                       \
+                                                        \
 /* ESCAPE used to transition to 2nd RSID set */         \
+                                                        \
         ELEM_(6, ESCAPE, NUM_MODES)                     \
                                                         \
         ELEM_(1, BPSK31, MODE_PSK31)                    \
@@ -200,7 +225,7 @@ const RSIDs cRsId::rsid_ids_1[] = { RSID_LIST };
 const int cRsId::rsid_ids_size1 = sizeof(rsid_ids_1)/sizeof(*rsid_ids_1) - 1;
 
 //======================================================================
-/*        ELEM_(263, ESCAPE2, NUM_MODES)                  \ */
+/*        ELEM_(6, ESCAPE2, NUM_MODES)                  \ */
 
 #define RSID_LIST2                                      \
         ELEM2_(450, PSK63RX4, MODE_4X_PSK63R)           \
@@ -248,6 +273,9 @@ const int cRsId::rsid_ids_size1 = sizeof(rsid_ids_1)/sizeof(*rsid_ids_1) - 1;
         ELEM2_(681, DOMINOEX_88, MODE_DOMINOEX88)       \
                                                         \
         ELEM2_(687, MFSK31, MODE_MFSK31)                \
+        												\
+        ELEM2_(1026, MFSK64L, MODE_MFSK64L)             \
+        ELEM2_(1029, MFSK128L, MODE_MFSK128L)           \
                                                         \
         ELEM2_(0, NONE2, NUM_MODES)
 
