@@ -34,7 +34,6 @@
 #include "thor.h"
 #include "trx.h"
 #include "fl_digi.h"
-#include "fft.h"
 #include "filters.h"
 #include "misc.h"
 #include "sound.h"
@@ -303,8 +302,8 @@ thor::thor(trx_mode md) : hilbert(0), fft(0), filter_reset(false)
 	prev1symbol = prev2symbol = 0;
 
 	if ( mode == MODE_THOR100 || mode == MODE_THOR50x1 || mode == MODE_THOR50x2 || mode == MODE_THOR25x4 ) {
-		Enc = new encoder (GALILEO_K, GALILEO_POLY1, GALILEO_POLY2);
-		Dec = new viterbi (GALILEO_K, GALILEO_POLY1, GALILEO_POLY2);
+		Enc = new encoder (THOR_K15, K15_POLY1, K15_POLY2);
+		Dec = new viterbi (THOR_K15, K15_POLY1, K15_POLY2);
 		Dec->settraceback (PATHMEM-1); // Long constraint length codes require longer traceback
 	} else {
 		Enc = new encoder (THOR_K, THOR_POLY1, THOR_POLY2);
@@ -325,7 +324,7 @@ thor::thor(trx_mode md) : hilbert(0), fft(0), filter_reset(false)
 //=====================================================================
 // rx modules
 
-complex thor::mixer(int n, const complex& in)
+cmplx thor::mixer(int n, const cmplx& in)
 {
 	double f;
 // first IF mixer (n == 0) plus
@@ -337,7 +336,7 @@ complex thor::mixer(int n, const complex& in)
 		f = THORFIRSTIF - THORBASEFREQ - bandwidth*0.5 + (samplerate / symlen) * ( (double)n / paths);
 
 	double phase_n = phase[n];
-	complex z( cos(phase_n), sin(phase_n) );
+	cmplx z( cos(phase_n), sin(phase_n) );
 	z *= in;
 	phase_n -= TWOPI * f / samplerate;
 	if (phase_n > M_PI)
@@ -464,8 +463,9 @@ void thor::decodesymbol()
 void thor::softdecodesymbol()
 {
 	unsigned char one, zero;
-	int c, nextmag=127;
-	static int lastc=0, lastmag=0, nowmag=0;
+	int c, nextmag=127, rawdoppler=0;
+	static int lastc=0, lastmag=0, nowmag=0, prev1rawdoppler=0;
+	static double lastdoppler=0, nowdoppler=0;
 	unsigned char lastsymbols[4];
 	bool outofrange=false;
 
@@ -484,11 +484,40 @@ void thor::softdecodesymbol()
 			}
 		}
 #if SOFTPROFILE
-		LOG_INFO("\nSymbol: %3d; DELTAf: +%3d",currsymbol, c);
+		LOG_INFO("Symbol: %3d; DELTAf: +%3d",currsymbol, c);
 #endif
 	}
 	c -= 2;
 	if (c < 0) c += THORNUMTONES;
+	
+		
+	// Calculate soft-doppler / frequency-error of the symbol
+	// For a perfect & undistorted symbol, rawdoppler will == 0 (be a perfect multiple of paths*doublespaced)
+	rawdoppler = (currsymbol - prev1symbol) % (paths * doublespaced) ; 
+#if SOFTPROFILE
+	LOG_INFO("Raw Doppler: %3d", rawdoppler);
+#endif
+	if ( 0 == rawdoppler) 
+		nowdoppler = 1.0f; // Perfect symbol: assign probability = 100%
+	else {
+		// Detect modem "de-sync + immediate re-sync" events and reverse the incurred soft-penalty
+		// Probability of these events increases as baudrate increases
+		if ( -1 * prev1rawdoppler == rawdoppler) { 
+			rawdoppler = 0;
+			lastdoppler = 1.0f;
+		}
+		// calculate the nowdoppler soft-value as a probability >= 50%
+		// centering the "50% confidence point" directly between two symbols.
+		if ( abs(rawdoppler) <= paths * doublespaced / 2  )
+			nowdoppler = 1.0 - ((1.0 / (paths * doublespaced)) * abs(rawdoppler)) ;
+		else
+			nowdoppler = 0.0 + ((1.0 / (paths * doublespaced)) * abs(rawdoppler)) ;
+	}
+	
+	prev1rawdoppler = rawdoppler; // save raw-value for comparison on next run
+#if SOFTPROFILE
+	LOG_INFO("Doppler Confidence: %3.1f", nowdoppler);
+#endif
 
 // Since the THOR modem is differential, when an outofrange error occurs
 // there are 2 possibilities:
@@ -516,6 +545,9 @@ void thor::softdecodesymbol()
 		nowmag /= 16;
 		nextmag /= 16;
 	}
+	
+	// Apply the soft-doppler probability to the previous symbol's soft-magnitude
+	lastmag *= lastdoppler;
 
 	if (lastmag <= 0) { // puncture
 		one = 128;
@@ -531,9 +563,9 @@ void thor::softdecodesymbol()
 	}
 
 #if SOFTPROFILE
-	LOG_INFO("next mag %.3d | now mag %.3d | last mag %.3d",nextmag, nowmag, lastmag);
 	if (outofrange) LOG_INFO("%s","outofrange");
 	if (staticburst) LOG_INFO("%s","staticburst");
+	LOG_INFO("next mag %.3d | now mag %.3d | last mag %.3d \n",nextmag, nowmag, lastmag);
 #endif
 
 	lastsymbols[3] = (lastc & 1) == 1 ? one : zero ; lastc /= 2;
@@ -549,6 +581,7 @@ void thor::softdecodesymbol()
 	lastc = c;
 	lastmag = nowmag;
 	nowmag = nextmag;
+	lastdoppler = nowdoppler;
 }
 
 int thor::harddecode()
@@ -562,7 +595,7 @@ int thor::harddecode()
 	for (int i = 0; i < MAXPATHS; i++) cwi[i] = false;
 
 	for (int i = 0; i < paths * numbins; i++)
-		avg += pipe[pipeptr].vector[i].mag();
+		avg += abs(pipe[pipeptr].vector[i]);
 	avg /= (paths * numbins);
 
 	if (avg < 1e-10) avg = 1e-10;
@@ -575,7 +608,7 @@ int thor::harddecode()
 		for (int j = 1; j <= numtests; j++) {
 			int p = pipeptr - j;
 			if (p < 0) p += twosym;
-			cwmag = (pipe[j].vector[i].mag())/numtests;
+			cwmag = abs(pipe[j].vector[i])/numtests;
 			if (cwmag >= 50.0 * (1.0 - progdefaults.ThorCWI) * avg) count++;
 		}
 		cwi[i] = (count == numtests);
@@ -583,7 +616,7 @@ int thor::harddecode()
 
 	for (int i = 0; i <  paths * numbins ; i++) {
 		if (cwi[i] == false) {
-			x = pipe[pipeptr].vector[i].mag();
+			x = abs(pipe[pipeptr].vector[i]);
 			if (x > max) {
 				max = x;
 				symbol = i;
@@ -628,7 +661,7 @@ int thor::softdecode()
 	for (int i = lowest_tone; i < highest_tone; i++)
 	{
 		if ( !lastCWI[i]  ) {
-			avg += pipe[pipeptr].vector[i].mag();
+			avg += abs(pipe[pipeptr].vector[i]);
 			avgcount++;
 		}
 	}
@@ -642,7 +675,7 @@ int thor::softdecode()
 		max = 0.0;
 
 		for (int i = lowest_tone; i < highest_tone; i++) {
-		  	x = pipe[pipeptr].vector[i].mag();
+		  	x = abs(pipe[pipeptr].vector[i]);
 			if ( x > max && !nextCWI[i-1] && !nextCWI[i] && !nextCWI[i+1] ) {
 				max = x;
 				symbol = i;
@@ -725,14 +758,14 @@ void thor::update_syncscope()
 //LOG_INFO("%s", "cleared videodata");
 	if (!progStatus.sqlonoff || metric >= progStatus.sldrSquelchValue) {
 		for (int i = 0; i < paths * numbins; i++ ) {
-			mag = pipe[pipeptr].vector[i].mag();
+			mag = abs(pipe[pipeptr].vector[i]);
 			if (max < mag) max = mag;
 			if (min > mag) min = mag;
 		}
 		range = max - min;
 		for (int i = 0; i < paths * numbins; i++ ) {
 			if (range > 2) {
-				mag = (pipe[pipeptr].vector[i].mag() - min) / range + 0.0001;
+				mag = (abs(pipe[pipeptr].vector[i]) - min) / range + 0.0001;
 				mag = 1 + 2 * log10(mag);
 				if (mag < 0) mag = 0;
 			} else
@@ -747,7 +780,7 @@ void thor::update_syncscope()
 	if (!progStatus.sqlonoff || metric >= progStatus.sldrSquelchValue) {
 		for (unsigned int i = 0, j = 0; i < THORSCOPESIZE; i++) {
 			j = (pipeptr + i * twosym / THORSCOPESIZE + 1) % (twosym);
-			scopedata[i] = vidfilter[i]->run(pipe[j].vector[prev1symbol].mag());
+			scopedata[i] = vidfilter[i]->run(abs(pipe[j].vector[prev1symbol]));
 		}
 	}
 	set_scope(scopedata, THORSCOPESIZE);
@@ -767,7 +800,7 @@ void thor::synchronize()
 		return;
 
 	for (unsigned int i = 0, j = pipeptr; i < twosym; i++) {
-		val = (pipe[j].vector[prev1symbol]).mag();
+		val = abs(pipe[j].vector[prev1symbol]);
 		if (val > max) {
 			max = val;
 			syn = i;
@@ -786,8 +819,9 @@ void thor::synchronize()
 
 void thor::eval_s2n()
 {
-	double s = pipe[pipeptr].vector[currsymbol].mag();
-	double n = (THORNUMTONES - 1) * pipe[(pipeptr + symlen) % twosym].vector[currsymbol].mag();
+	double s = abs(pipe[pipeptr].vector[currsymbol]);
+	double n = (THORNUMTONES - 1) * 
+				abs( pipe[(pipeptr + symlen) % twosym].vector[currsymbol]);
 
 	sig = decayavg( sig, s, s - sig > 0 ? 4 : 20);
 	noise = decayavg( noise, n, 64);
@@ -829,8 +863,8 @@ void thor::eval_s2n()
 
 int thor::rx_process(const double *buf, int len)
 {
-	complex zref, *zp;
-	complex zarray[1];
+	cmplx zref, *zp;
+	cmplx zarray[1];
 	int n;
 
 	if (slowcpu != progdefaults.slowcpu) {
@@ -842,7 +876,8 @@ int thor::rx_process(const double *buf, int len)
 
 	while (len) {
 // create analytic signal at first IF
-		zref.re = zref.im = *buf++;
+		zref = cmplx( *buf, *buf );
+		buf++;
 		hilbert->run(zref, zref);
 		zref = mixer(0, zref);
 
@@ -857,13 +892,13 @@ int thor::rx_process(const double *buf, int len)
 
 		if (n) {
 			for (int i = 0; i < n; i++) {
-				complex * pipe_pipeptr_vector = pipe[pipeptr].vector ;
-				const complex zp_i = zp[i];
+				cmplx * pipe_pipeptr_vector = pipe[pipeptr].vector ;
+				const cmplx zp_i = zp[i];
 // process THORMAXFFTS sets of sliding FFTs spaced at 1/THORMAXFFTS bin intervals each of which
 // is a matched filter for the current symbol length
 				for (int k = 0; k < paths; k++) {
 // shift in frequency to base band for the sliding DFTs
-					const complex z = mixer(k + 1, zp_i );
+					const cmplx z = mixer(k + 1, zp_i );
 // copy current vector to the pipe interleaving the FFT vectors
 					binsfft[k]->run(z, pipe_pipeptr_vector + k, paths );
 				}
@@ -875,7 +910,7 @@ int thor::rx_process(const double *buf, int len)
 					else 
 						currsymbol = harddecode();
 					
-					currmag = pipe_pipeptr_vector[currsymbol].mag();
+					currmag = abs(pipe_pipeptr_vector[currsymbol]);
 					eval_s2n();
 
 					if (progdefaults.THOR_SOFTBITS)
@@ -933,7 +968,7 @@ void thor::sendtone(int tone, int duration)
 
 void thor::sendsymbol(int sym)
 {
-	complex z;
+	cmplx z;
     int tone;
 
 	tone = (txprevtone + 2 + sym) % THORNUMTONES;
