@@ -36,6 +36,7 @@
 #include "configuration.h"
 #include "waterfall.h"
 #include "qrunner.h"
+#include "macros.h"
 
 #include "status.h"
 #include "debug.h"
@@ -55,6 +56,8 @@ modem *mfsk22_modem = 0;
 modem *mfsk31_modem = 0;
 modem *mfsk64_modem = 0;
 modem *mfsk128_modem = 0;
+modem *mfsk64l_modem = 0;
+modem *mfsk128l_modem = 0;
 
 modem *wefax576_modem = 0;
 modem *wefax288_modem = 0;
@@ -179,6 +182,11 @@ double modem::frequency = 1000;
 double modem::tx_frequency = 1000;
 bool   modem::freqlock = false;
 
+// For xml socket command
+unsigned long modem::tx_sample_count = 0;
+unsigned int  modem::tx_sample_rate  = 0;
+bool modem::XMLRPC_CPS_TEST = false;
+
 modem::modem()
 {
 	scptr = 0;
@@ -200,6 +208,8 @@ modem::modem()
 	PTTphaseacc = 0.0;
 	s2n_ncount = s2n_sum = s2n_sum2 = s2n_metric = 0.0;
 	s2n_valid = false;
+
+	bandwidth = 0.0;
 }
 
 // modem types CW and RTTY do not use the base init()
@@ -421,6 +431,8 @@ void modem::ModulateXmtr(double *buffer, int len)
 {
 	if (unlikely(!scard)) return;
 
+	tx_sample_count += len;
+
 	if (progdefaults.PTTrightchannel) {
 		for (int i = 0; i < len; i++)
 			PTTchannel[i] = PTTnco();
@@ -428,13 +440,18 @@ void modem::ModulateXmtr(double *buffer, int len)
 		return;
 	}
 
-	if (progdefaults.viewXmtSignal)
+	if (progdefaults.viewXmtSignal &&
+		!(PERFORM_CPS_TEST || active_modem->XMLRPC_CPS_TEST))
 		trx_xmit_wfall_queue(samplerate, buffer, (size_t)len);
 
 	if (withnoise && progdefaults.noise) add_noise(buffer, len);
 
 	double mult = pow(10, progdefaults.txlevel / 20.0);
-	for (int i = 0; i < len; i++) buffer[i] *= mult;
+	for (int i = 0; i < len; i++) {
+		if (buffer[i] < -1.0) buffer[i] = -1.0;
+		if (buffer[i] > 1.0) buffer[i] = 1.0;
+		buffer[i] *= mult;
+	}
 
 	try {
 		unsigned n = 4;
@@ -458,14 +475,22 @@ void modem::ModulateStereo(double *left, double *right, int len)
 {
 	if (unlikely(!scard)) return;
 
-	if (progdefaults.viewXmtSignal)
+	tx_sample_count += len;
+
+	if (progdefaults.viewXmtSignal &&
+		!(PERFORM_CPS_TEST || active_modem->XMLRPC_CPS_TEST))
 		trx_xmit_wfall_queue(samplerate, left, (size_t)len);
 
 	if (withnoise && progdefaults.noise) add_noise(left, len);
 
-	double mult = pow(10, progdefaults.txlevel / 20.0);
-	for (int i = 0; i < len; i++) left[i] *= mult;
-
+	double mult = 0.98 * pow(10, progdefaults.txlevel / 20.0);
+	for (int i = 0; i < len; i++) {
+		if (right[i] < -1.0) right[i] = -1.0;
+		if (right[i] > 1.0) right[i] = 1.0;
+		if (left[i] < -1.0) left[i] = -1.0;
+		if (left[i] > 1.0) left[i] = 1.0;
+		left[i] *= mult;
+	}
 	try {
 		unsigned n = 4;
 		while (scard->Write_stereo(left, right, len) == 0 && --n);
@@ -694,7 +719,7 @@ struct mfntchr  { char c; int byte[MAXROWS]; };
 extern mfntchr  idch1[]; // original id font definition
 extern mfntchr  idch2[]; // extended id font definition
 
-static int symbols[MAXCHARS];
+static int id_symbols[MAXCHARS];
 
 static C_FIR_filter vidfilt;
 
@@ -723,7 +748,7 @@ void modem::wfid_send(int numchars)
 	for (i = 0; i < IDSYMLEN; i++) {
 		val = 0.0;
 		for (k = 0; k < numchars; k++) {
-			sym = symbols[numchars - k - 1];
+			sym = id_symbols[numchars - k - 1];
 			for (j = 0; j < NUMCOLS; j++) {
 				if (sym & 1)
 					val += sin(wfid_w[j + k * NUMCOLS] * i);
@@ -759,9 +784,9 @@ void modem::wfid_sendchars(string s)
 	for (int row = 0; row < NUMROWS; row++) {
 		for (int i = 0; i < len; i++) {
 			if (useIDSMALL)
-				symbols[i] = idch1[n[i]].byte[NUMROWS - 1 - row];
+				id_symbols[i] = idch1[n[i]].byte[NUMROWS - 1 - row];
 			else
-				symbols[i] = idch2[n[i]].byte[NUMROWS - 1 - row];
+				id_symbols[i] = idch2[n[i]].byte[NUMROWS - 1 - row];
 		}
 		wfid_send(len);
 		if (stopflag)
@@ -851,7 +876,7 @@ void modem::wfid_text(const string& s)
 			break;
 	}
 // blank lines
-	for (int i = 0; i < vidwidth; i++) symbols[i] = 0;
+	for (int i = 0; i < vidwidth; i++) id_symbols[i] = 0;
 	wfid_send(vidwidth);
 	wfid_send(vidwidth);
 
