@@ -34,6 +34,9 @@
 
 #define null_bw 1
 
+// a NULLMODEM and will be instantiated before the dynamic member wf, 
+// digiscope, and fl_digi_main, the main dialog
+
 NULLMODEM:: NULLMODEM() : modem() 
 {
 	mode = MODE_NULL;
@@ -50,19 +53,21 @@ void  NULLMODEM::tx_init(SoundBase *sc)
 
 void  NULLMODEM::rx_init()
 {
-	put_MODEstatus(mode);
+	if (fl_digi_main)
+		put_MODEstatus(mode);
 }
 
 void NULLMODEM::init()
 {
 	modem::init();
 	rx_init();
-	digiscope->mode(Digiscope::SCOPE);
+	if (digiscope)
+		digiscope->mode(Digiscope::SCOPE);
 }
 
 void NULLMODEM::restart()
 {
-	set_bandwidth(null_bw);
+	if (wf) set_bandwidth(null_bw);
 }
 
 
@@ -83,9 +88,12 @@ int NULLMODEM::rx_process(const double *buf, int len)
 int NULLMODEM::tx_process()
 {
 	MilliSleep(10);
+	if (!fl_digi_main) return 0;
+
 	if ( get_tx_char() == GET_TX_CHAR_ETX || stopflag) {
 		stopflag = false;
 		return -1;
 	}
 	return 0;
 }
+
