@@ -128,21 +128,19 @@ WFdisp::WFdisp (int x0, int y0, int w0, int h0, char *lbl) :
 	scline			= new uchar[scale_width];
 	fft_sig_img 	= new uchar[image_area];
 	sig_img			= new uchar[sig_image_area];
-	pwr				= new double[IMAGE_WIDTH];
+	pwr				= new wf_fft_type[IMAGE_WIDTH];
 	fft_db			= new short int[image_area];
 	tmp_fft_db		= new short int[image_area];
-	circbuff		= new double[FFT_LEN * 2];
-	fftout			= new double[FFT_LEN * 2];
-	wfft			= new Cfft(FFT_LEN);
-	fftwindow	   = new double[FFT_LEN * 2];
+	circbuff		= new double[FFT_LEN];
+	wfbuf			= new wf_cpx_type[FFT_LEN];
+	wfft			= new g_fft<wf_fft_type>(FFT_LEN);
+	fftwindow		= new double[FFT_LEN];
 	setPrefilter(progdefaults.wfPreFilter);
 
-	for (int i = 0; i < FFT_LEN*2; i++)
-		circbuff[i] = fftout[i] = 0.0;
+	memset(circbuff, 0, FFT_LEN * sizeof(double));
 
 	mag = 1;
 	step = 4;
-	dispcolor = true;
 	offset = 0;
 	sigoffset = 0;
 	ampspan = 75;
@@ -205,6 +203,7 @@ void WFdisp::initMarkers() {
 // draw a marker of specified width and colour centred at freq and clrM
 inline void WFdisp::makeMarker_(int width, const RGB* color, int freq, const RGB* clrMin, RGB* clrM, const RGB* clrMax)
 {
+	if (!active_modem) return;
 	trx_mode marker_mode = active_modem->get_mode();
 	if (marker_mode == MODE_RTTY) {
 	// rtty has two bandwidth indicators on the waterfall
@@ -341,7 +340,6 @@ void WFdisp::makeMarker()
 	}
 }
 
-
 void WFdisp::makeScale() {
 	uchar *gmap = scaleimage;
 	int hwidth = step / 2;
@@ -480,11 +478,11 @@ double WFdisp::powerDensityMaximum(int bw_nb, const int (*bw)[2]) const
 void WFdisp::setPrefilter(int v)
 {
 	switch (v) {
-	case WF_FFT_RECTANGULAR: RectWindow(fftwindow, FFT_LEN*2); break;
-	case WF_FFT_BLACKMAN: BlackmanWindow(fftwindow, FFT_LEN*2); break;
-	case WF_FFT_HAMMING: HammingWindow(fftwindow, FFT_LEN*2); break;
-	case WF_FFT_HANNING: HanningWindow(fftwindow, FFT_LEN*2); break;
-	case WF_FFT_TRIANGULAR: TriangularWindow(fftwindow, FFT_LEN*2); break;
+	case WF_FFT_RECTANGULAR: RectWindow(fftwindow, FFT_LEN); break;
+	case WF_FFT_BLACKMAN: BlackmanWindow(fftwindow, FFT_LEN); break;
+	case WF_FFT_HAMMING: HammingWindow(fftwindow, FFT_LEN); break;
+	case WF_FFT_HANNING: HanningWindow(fftwindow, FFT_LEN); break;
+	case WF_FFT_TRIANGULAR: TriangularWindow(fftwindow, FFT_LEN); break;
 	}
 	prefilter = v;
 }
@@ -501,53 +499,50 @@ void WFdisp::processFFT() {
 	if (prefilter != progdefaults.wfPreFilter)
 		setPrefilter(progdefaults.wfPreFilter);
 
-		const double scale = ( (double)SC_SMPLRATE / srate ) * ( FFT_LEN / 2000.0 );
+	wf_fft_type scale = ( 1.0 * SC_SMPLRATE / srate ) * ( FFT_LEN / 8000.0);
 
-	if (dispcnt == 0) {
-		int step = 8 / progdefaults.latency;
+	if (--dispcnt == 0) {
+		static const int log2disp100 = log2disp(-100);
+		double vscale = 2.0 / FFT_LEN;
 
-		int last_i = FFT_LEN * 2 / step;
-		for (int i = 0; i < last_i; i++)
-		fftout[i] = fftwindow[i * step] * circbuff[i] * step;
-		/// Zeroes only the last elements.
-		memset (fftout + last_i , 0, ( FFT_LEN*2 - last_i ) *sizeof(double));
+		memset(wfbuf, 0, FFT_LEN * sizeof(*wfbuf));
+		void *pv = static_cast<void*>(wfbuf);
+		wf_fft_type *pbuf = static_cast<wf_fft_type*>(pv);
 
-		wfft->rdft(fftout);
-FL_LOCK_D();
-		const int log2disp100 = log2disp(-100);
-		for (int i = 0; i <= progdefaults.LowFreqCutoff; i++) {
-			pwr[i] = 0.0;
-			fft_db[ptrFFTbuff * IMAGE_WIDTH + i] = log2disp100;
-		}
+		int latency = progdefaults.wf_latency;
+		if (latency < 1) latency = 1;
+		if (latency > 16) latency = 16;
+		int nsamples = FFT_LEN * latency / 16;
+		vscale *= sqrt(16.0 / latency);
+		for (int i = 0; i < nsamples; i++)
+			pbuf[i] = fftwindow[i * 16 / latency] * circbuff[i] * vscale;
 
+		wfft->RealFFT(wfbuf);
+
+		memset(pwr, 0, progdefaults.LowFreqCutoff * sizeof(wf_fft_type));
+		memset(&fft_db[ptrFFTbuff * IMAGE_WIDTH],
+				log2disp100,
+				progdefaults.LowFreqCutoff * sizeof(*fft_db));
+
+		int n = 0;
 		for (int i = progdefaults.LowFreqCutoff + 1; i < IMAGE_WIDTH; i++) {
-			int n = (int)(scale * i) & ~1 ; // Even number.
-			double pw = fftout[n]*fftout[n] + fftout[n+1]*fftout[n+1];
-			pwr[i] = pw;
-			int ffth = (int)(10.0 * log10(pw + 1e-10) );
+			n = round(scale * i);
+			pwr[i] = norm(wfbuf[n]);
+			int ffth = round(10.0 * log10(pwr[i] + 1e-10) );
 			fft_db[ptrFFTbuff * IMAGE_WIDTH + i] = log2disp(ffth);
 		}
 
 		ptrFFTbuff--;
 		if (ptrFFTbuff < 0) ptrFFTbuff += image_height;
-FL_UNLOCK_D();
-	}
 
-	if (dispcnt == 0) {
-FL_LOCK_D();
-		if (dispcnt == 0) {
-			for (int i = 0; i < image_height; i++) {
-				int j = (i + 1 + ptrFFTbuff) % image_height;
-				memmove( (void *)(tmp_fft_db + i * IMAGE_WIDTH),
-						 (void *)(fft_db + j * IMAGE_WIDTH),
-						 IMAGE_WIDTH * sizeof(short int));
-			}
+		for (int i = 0; i < image_height; i++) {
+			int j = (i + 1 + ptrFFTbuff) % image_height;
+			memmove( (void *)(tmp_fft_db + i * IMAGE_WIDTH),
+					 (void *)(fft_db + j * IMAGE_WIDTH),
+					 IMAGE_WIDTH * sizeof(short int));
 		}
 		redraw();
-FL_UNLOCK_D();
-	}
 
-	if (dispcnt == 0) {
 		if (srate == 8000)
 			dispcnt = wfspeed;
 		else if (srate == 11025)
@@ -556,9 +551,9 @@ FL_UNLOCK_D();
 		else
 			dispcnt = wfspeed * 8 / 3;
 	}
-	--dispcnt;
 }
-void WFdisp::process_analog (double *sig, int len) {
+
+void WFdisp::process_analog (wf_fft_type *sig, int len) {
 	int h1, h2, h3;
 	int sigy, sigpixel, ynext, graylevel;
 	h1 = h()/8 - 1;
@@ -579,7 +574,7 @@ FL_LOCK_D();
 		ynext = (int)(h2 * sig[cbc]);
 		if (ynext < -h2) ynext = -h2;
 		if (ynext > h2) ynext = h2;
-		cbc = (cbc + 1) % (FFT_LEN *2);
+		cbc = (cbc + 1) % (FFT_LEN);
 		for (; sigy < ynext; sigy++) sig_img[sigpixel -= IMAGE_WIDTH] = graylevel;
 		for (; sigy > ynext; sigy--) sig_img[sigpixel += IMAGE_WIDTH] = graylevel;
 		sig_img[sigpixel++] = graylevel;
@@ -603,27 +598,29 @@ void WFdisp::sig_data( double *sig, int len, int sr )
 	// if sound card sampling rate changed reset the waterfall buffer
 	if (srate != sr) {
 		srate = sr;
-		memset (circbuff, 0, FFT_LEN * 2 * sizeof(double));
+		memset(circbuff, 0, FFT_LEN * sizeof(*circbuff));
 		ptrCB = 0;
 	}
 
+	memmove((void*)circbuff,
+			(void*)(circbuff + len), 
+			(size_t)((FFT_LEN - len)*sizeof(wf_fft_type)));
+	memcpy((void*)&circbuff[FFT_LEN-len], 
+			(void*)sig,
+			(size_t)(len)*sizeof(double));
+
 	{
 		overload = false;
 		double overval, peak = 0.0;
-		memmove((void*)circbuff,
-				(void*)(circbuff + len), 
-				(size_t)((FFT_LEN *2 - len)*sizeof(double)));
-		memmove((void*)(circbuff + (FFT_LEN*2-len)),
-				(void*)sig,
-				(size_t)(len*sizeof(double)));
 		for (int i = 0; i < len; i++) {
 			overval = fabs(sig[i]);
 			if (overval > peak) peak = overval;
 		}
 		peakaudio = 0.1 * peak + 0.9 * peakaudio;
 	}
+
 	if (mode == SCOPE)
-		process_analog(circbuff, FFT_LEN * 2);
+		process_analog(circbuff, FFT_LEN);
 	else
 		processFFT();
 
@@ -631,7 +628,7 @@ void WFdisp::sig_data( double *sig, int len, int sr )
 
 update_freq:
 	static char szFrequency[14];
-	if (rfc != 0) { // use a boolean for the waterfall
+	if (active_modem && rfc != 0) { // use a boolean for the waterfall
 		int cwoffset = 0;
 		int rttyoffset = 0;
 		trx_mode mode = active_modem->get_mode();
@@ -824,7 +821,7 @@ void WFdisp::update_waterfall() {
 // transfer the fft history data into the WF image
 	short int * __restrict__ p1, * __restrict__ p2;
 	RGBI * __restrict__ p3, * __restrict__ p4;
-	p1 = tmp_fft_db + offset;
+	p1 = tmp_fft_db + offset + step/2;
 	p2 = p1;
 	p3 = fft_img;
 	p4 = p3;
@@ -844,22 +841,22 @@ case Step: for (int row = 0; row < image_height; row++) { \
 
 	if (progdefaults.WFaveraging) {
 		switch(step) {
-			UPD_LOOP( 4, (*p2+ *(p2+1)+ *(p2+2)+ *(p2+3))/4 );
-			UPD_LOOP( 2, (*p2  + *(p2+1))/2 );
+			UPD_LOOP( 4, (*p2 + *(p2+1) + *(p2+2) + *(p2-1) + *(p2-1))/5 );
+			UPD_LOOP( 2, (*p2 + *(p2+1) + *(p2-1))/3 );
 			UPD_LOOP( 1, *p2 );
 			default:;
 		}
 	} else {
 		switch(step) {
-			UPD_LOOP( 4, MAX( MAX ( MAX ( *p2, *(p2+1) ), *(p2+2) ), *(p2+3) ) );
-			UPD_LOOP( 2, MAX( *p2, *(p2+1) ) );
+			UPD_LOOP( 4, MAX( MAX( MAX ( MAX ( *p2, *(p2+1) ), *(p2+2) ), *(p2-2) ), *(p2-1) ) );
+			UPD_LOOP( 2, MAX( MAX( *p2, *(p2+1) ), *(p2-1) ) );
 			UPD_LOOP( 1, *p2 );
 			default:;
 		}
 	}
 #undef UPD_LOOP
 
-	if (progdefaults.UseBWTracks) {
+	if (active_modem && progdefaults.UseBWTracks) {
 		int bw_lo = bandwidth / 2;
 		int bw_hi = bandwidth / 2;
 		trx_mode mode = active_modem->get_mode();
@@ -924,7 +921,8 @@ void WFdisp::drawcolorWF() {
 
 	update_waterfall();
 
-	if (wantcursor && (progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine) ) {
+	if (active_modem && wantcursor && 
+		(progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine) ) {
 		trx_mode mode = active_modem->get_mode();
 		int bw_lo = bandwidth / 2;
 		int bw_hi = bandwidth / 2;
@@ -962,44 +960,6 @@ void WFdisp::drawcolorWF() {
 	drawScale();
 }
 
-// following method is not used in versions > 3.12
-void WFdisp::drawgrayWF() {
-	uchar *pixmap = (uchar*)fft_img;
-
-	update_waterfall();
-
-	if (wantcursor && (progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine) ) {
-		trx_mode mode = active_modem->get_mode();
-		int bw_lo = bandwidth / 2;
-		int bw_hi = bandwidth / 2;
-		if (mode >= MODE_MT63_500S && mode <= MODE_MT63_2000L)
-			bw_hi = bw_hi * 31 / 32;
-		RGBI  *pos0 = (fft_img + cursorpos);
-		RGBI  *pos1 = (fft_img + cursorpos - bw_lo/step);
-		RGBI  *pos2 = (fft_img + cursorpos + bw_hi/step);
-		if (pos1 >= fft_img && pos2 < fft_img + disp_width)
-			for (int y = 0; y < image_height; y ++) {
-				if (progdefaults.UseCursorLines)
-					*pos1 = *pos2 = progdefaults.cursorLineRGBI;
-				if (progdefaults.UseCursorCenterLine)
-					*pos0 = progdefaults.cursorCenterRGBI;
-				pos0 += disp_width;
-				pos1 += disp_width;
-				pos2 += disp_width;
-			}
-	}
-
-	fl_color(FL_BLACK);
-	fl_rectf(x(), y(), w(), WFSCALE + WFMARKER + WFTEXT + image_height);
-
-	fl_draw_image_mono(
-		pixmap + 3,
-		x(), y() + WFSCALE + WFMARKER + WFTEXT,
-		disp_width, image_height,
-		sizeof(RGBI), disp_width * sizeof(RGBI));
-	drawScale();
-}
-
 void WFdisp::drawspectrum() {
 	int sig;
 	int ynext,
@@ -1041,7 +1001,8 @@ void WFdisp::drawspectrum() {
 				pos2 += IMAGE_WIDTH/step;
 			}
 	}
-	if (wantcursor && (progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine)) {
+	if (active_modem && wantcursor && 
+		(progdefaults.UseCursorLines || progdefaults.UseCursorCenterLine)) {
 		trx_mode mode = active_modem->get_mode();
 		int bw_lo = bandwidth / 2;
 		int bw_hi = bandwidth / 2;
@@ -1111,10 +1072,7 @@ void WFdisp::draw() {
 		break;
 	case WATERFALL :
 	default:
-		if (dispcolor)
-			drawcolorWF();
-		else
-			drawgrayWF();
+		drawcolorWF();
 		drawMarker();
 	}
 }
@@ -1157,13 +1115,14 @@ void carrier_cb(Fl_Widget *w, void *v) {
 	int selfreq = (int) cntr->value();
 	if (selfreq > progdefaults.HighFreqCutoff) selfreq = progdefaults.HighFreqCutoff - wf->wfdisp->Bandwidth() / 2;
 	stopMacroTimer();
-	active_modem->set_freq(selfreq);
+	if (active_modem) active_modem->set_freq(selfreq);
 	wf->wfdisp->carrier(selfreq);
 	restoreFocus();
 }
 
 void do_qsy(bool dir)
 {
+	if (!active_modem) return;
 	static vector<qrg_mode_t> qsy_stack;
 	qrg_mode_t m;
 
@@ -1238,6 +1197,7 @@ void rate_cb(Fl_Widget *w, void *v) {
 
 void xmtrcv_cb(Fl_Widget *w, void *vi)
 {
+	if (!active_modem) return;
 	FL_LOCK_D();
 	Fl_Light_Button *b = (Fl_Light_Button *)w;
 	int v = b->value();
@@ -1262,6 +1222,7 @@ void xmtrcv_cb(Fl_Widget *w, void *vi)
 				AbortARQ();
 			if (progStatus.timer)
 				progStatus.timer = 0;
+			queue_reset();
 			active_modem->set_stopflag(true);
 		}
 	}
@@ -1270,6 +1231,7 @@ void xmtrcv_cb(Fl_Widget *w, void *vi)
 
 void xmtlock_cb(Fl_Widget *w, void *vi)
 {
+	if (!active_modem) return;
 	FL_LOCK_D();
 	Fl_Light_Button *b = (Fl_Light_Button *)w;
 	int v = b->value();
@@ -1328,7 +1290,9 @@ void ampspan_cb(Fl_Widget *w, void *v) {
 	restoreFocus();
 }
 
-void btnRev_cb(Fl_Widget *w, void *v) {
+void btnRev_cb(Fl_Widget *w, void *v) 
+{
+	if (!active_modem) return;
 	FL_LOCK_D();
 	waterfall *wf = (waterfall *)w->parent();
 	Fl_Light_Button *b = (Fl_Light_Button *)w;
@@ -1342,6 +1306,7 @@ void btnRev_cb(Fl_Widget *w, void *v) {
 
 void btnMem_cb(Fl_Widget *, void *menu_event)
 {
+	if (!active_modem) return;
 	static std::vector<qrg_mode_t> qrg_list;
 	enum { SELECT, APPEND, REPLACE, REMOVE, CLEAR };
 	int op = SELECT, elem = 0;
@@ -1435,6 +1400,7 @@ void btnMem_cb(Fl_Widget *, void *menu_event)
 }
 
 void waterfall::opmode() {
+	if (!active_modem) return;
 	int val = (int)active_modem->get_bandwidth();
 
 	wfdisp->carrier((int)CLAMP(
@@ -1516,7 +1482,7 @@ int waterfall::Carrier()
 
 void waterfall::Carrier(int f)
 {
-	active_modem->set_freq(f);
+	if (active_modem) active_modem->set_freq(f);
 }
 
 void waterfall::rfcarrier(long long cf) {
@@ -1545,7 +1511,7 @@ void waterfall::USB(bool b) {
 	if (wfdisp->USB() == b)
 		return;
 	wfdisp->USB(b);
-	active_modem->set_reverse(reverse);
+	if (active_modem) active_modem->set_reverse(reverse);
 	REQ(&viewer_redraw);
 }
 
@@ -1772,7 +1738,7 @@ int waterfall::handle(int event)
 
 	// this does not belong here, but we don't have access to this widget's
 	// handle method (or its parent's)
-	if (Fl::event_inside(MODEstatus)) {
+	if (active_modem && Fl::event_inside(MODEstatus)) {
 		trx_mode mode = active_modem->get_mode();
 		for (;;) {
 			mode = WCLAMP(mode + d, 0, NUM_MODES - 1);
@@ -1812,7 +1778,7 @@ static void hide_cursor(void *w)
 
 void waterfall::insert_text(bool check)
 {
-	if (check) {
+	if (active_modem && check) {
 		qrg_mode_t m;
 		m.rfcarrier = wf->rfcarrier();
 		m.carrier = active_modem->get_freq();
@@ -1839,6 +1805,7 @@ void waterfall::insert_text(bool check)
 
 static void find_signal_text(void)
 {
+	if (!active_modem) return;
 	int freq = active_modem->get_freq();
 	trx_mode mode = active_modem->get_mode();
 
@@ -1927,7 +1894,7 @@ int WFdisp::handle(int event)
 				if (!USB())
 					newrfc = -newrfc;
 				newrfc += rfcarrier();
-				qsy(newrfc, active_modem->get_freq());
+				qsy(newrfc, active_modem ? active_modem->get_freq() : 1500);
 				pxpos = xpos;
 				return 1;
 			}
@@ -1945,14 +1912,16 @@ int WFdisp::handle(int event)
 			if (progdefaults.WaterfallHistoryDefault)
 				bHistory = true;
 			newcarrier = cursorFreq(xpos);
-			newcarrier = (int)CLAMP(
-				newcarrier, 
-				progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2, 
-				progdefaults.HighFreqCutoff - active_modem->get_bandwidth() / 2);
-			active_modem->set_freq(newcarrier);
-			viewer_paste_freq(newcarrier);
-			if (!(Fl::event_state() & FL_SHIFT))
-				active_modem->set_sigsearch(SIGSEARCH);
+			if (active_modem) {
+				newcarrier = (int)CLAMP(
+					newcarrier, 
+					progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2, 
+					progdefaults.HighFreqCutoff - active_modem->get_bandwidth() / 2);
+				active_modem->set_freq(newcarrier);
+				viewer_paste_freq(newcarrier);
+				if (!(Fl::event_state() & FL_SHIFT))
+					active_modem->set_sigsearch(SIGSEARCH);
+			}
 			redrawCursor();
 			restoreFocus();
 			break;
@@ -1971,7 +1940,7 @@ int WFdisp::handle(int event)
 		switch (eb = Fl::event_button()) {
 		case FL_RIGHT_MOUSE:
 			tmp_carrier = false;
-			active_modem->set_freq(oldcarrier);
+			if (active_modem) active_modem->set_freq(oldcarrier);
 			redrawCursor();
 			restoreFocus();
 			// fall through
@@ -2029,11 +1998,13 @@ int WFdisp::handle(int event)
 		case FL_Left: case FL_Right:
 			if (k == FL_Left)
 				d = -d;
-			oldcarrier = newcarrier = (int)CLAMP(
-				carrier() + d, 
-				progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2, 
-				progdefaults.HighFreqCutoff - active_modem->get_bandwidth() / 2);
-			active_modem->set_freq(newcarrier);
+			if (active_modem) {
+				oldcarrier = newcarrier = (int)CLAMP(
+					carrier() + d, 
+					progdefaults.LowFreqCutoff + active_modem->get_bandwidth() / 2, 
+					progdefaults.HighFreqCutoff - active_modem->get_bandwidth() / 2);
+				active_modem->set_freq(newcarrier);
+			}
 			redrawCursor();
 			break;
 		case FL_Tab:
@@ -2084,29 +2055,32 @@ void waterfall::handle_mouse_wheel(int what, int d)
 		return;
 	case WF_AFC_BW:
 	{
-		trx_mode m = active_modem->get_mode();
-		if (m >= MODE_PSK_FIRST && m <= MODE_PSK_LAST) {
-			val = mailserver ? cntServerOffset : cntSearchRange;
-			msg_label = "Srch Rng";
+		if (active_modem) {
+			trx_mode m = active_modem->get_mode();
+			if (m >= MODE_PSK_FIRST && m <= MODE_PSK_LAST) {
+				val = mailserver ? cntServerOffset : cntSearchRange;
+				msg_label = "Srch Rng";
+			}
+			else if (m >= MODE_HELL_FIRST && m <= MODE_HELL_LAST) {
+				val = sldrHellBW;
+				msg_label = "BW";
+			}
+			else if (m == MODE_CW) {
+				val = sldrCWbandwidth;
+				msg_label = "BW";
+			}
+			else
+				return;
+			msg_fmt = "%s: %2.0f Hz";
 		}
-		else if (m >= MODE_HELL_FIRST && m <= MODE_HELL_LAST) {
-			val = sldrHellBW;
-			msg_label = "BW";
-		}
-		else if (m == MODE_CW) {
-			val = sldrCWbandwidth;
-			msg_label = "BW";
-		}
-		else
-			return;
-		msg_fmt = "%s: %2.0f Hz";
 		break;
 	}
 	case WF_SIGNAL_SEARCH:
-		if (d > 0)
-			active_modem->searchDown();
-		else
-			active_modem->searchUp();
+		if (d > 0) {
+			if (active_modem) active_modem->searchDown();
+		} else {
+			if (active_modem) active_modem->searchUp();
+		}
 		return;
 	case WF_SQUELCH:
 		val = sldrSquelch;
@@ -2129,11 +2103,11 @@ void waterfall::handle_mouse_wheel(int what, int d)
 	bool changed_save = progdefaults.changed;
 	val->do_callback();
 	progdefaults.changed = changed_save;
-	if (val == cntServerOffset || val == cntSearchRange)
-		active_modem->set_sigsearch(SIGSEARCH);
-	else if (val == sldrSquelch) // sldrSquelch gives focus to TransmitText
+	if (val == cntServerOffset || val == cntSearchRange) {
+		if (active_modem) active_modem->set_sigsearch(SIGSEARCH);
+	} else if (val == sldrSquelch) { // sldrSquelch gives focus to TransmitText
 		take_focus();
-
+	}
 	if (msg_fmt) {
 		char msg[60];
 		snprintf(msg, sizeof(msg), msg_fmt, msg_label, val->value());
