@@ -142,9 +142,7 @@ FTextRX::FTextRX(int x, int y, int w, int h, const char *l)
 	init_context_menu();
 	menu[RX_MENU_QUICK_ENTRY].clear();
 	menu[RX_MENU_SCROLL_HINTS].clear();
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 	menu[RX_MENU_WRAP].hide();
-#endif
 	// Replace the scrollbar widget
 	MVScrollbar* mvsb = new MVScrollbar(mVScrollBar->x(), mVScrollBar->y(),
 					    mVScrollBar->w(), mVScrollBar->h(), NULL);
@@ -153,9 +151,7 @@ FTextRX::FTextRX(int x, int y, int w, int h, const char *l)
 	remove(mVScrollBar);
 	delete mVScrollBar;
 	Fl_Group::add(mVScrollBar = mvsb);
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 	mFastDisplay = 1;
-#endif
 }
 
 FTextRX::~FTextRX()
@@ -213,11 +209,7 @@ int FTextRX::handle(int event)
 		}
 	case FL_MOVE: {
 		int p = xy_to_position(Fl::event_x(), Fl::event_y(), Fl_Text_Display_mod::CURSOR_POS);
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 		if ((unsigned char)sbuf->byte_at(p) >= CLICK_START + FTEXT_DEF) {
-#else
-		if (sbuf->character(p) >= CLICK_START + FTEXT_DEF) {
-#endif
 			if (cursor != FL_CURSOR_HAND)
 				window()->cursor(cursor = FL_CURSOR_HAND);
 			return 1;
@@ -257,7 +249,6 @@ out:
 /// @param attr The attribute (@see enum text_attr_e); RECV if omitted.
 ///
 
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 void FTextRX::add(unsigned int c, int attr)
 {
 	if (c == '\r')
@@ -354,53 +345,6 @@ void FTextRX::add(unsigned int c, int attr)
 		(mVScrollBar->value() >= mNBufferLines - mNVisibleLines + mVScrollBar->linesize() - 1))
 		show_insert_position();
 }
-#else
-void FTextRX::add(unsigned char c, int attr)
-{
-	if (c == '\r')
-		return;
-
-	// The user may have moved the cursor by selecting text or
-	// scrolling. Place it at the end of the buffer.
-	if (mCursorPos != tbuf->length())
-		insert_position(tbuf->length());
-
-	switch (c) {
-	case '\b':
-		// we don't call kf_backspace because it kills selected text
-		tbuf->remove(tbuf->length() - 1, tbuf->length());
-		sbuf->remove(sbuf->length() - 1, sbuf->length());
-		break;
-	case '\n':
-		// maintain the scrollback limit, if we have one
-		if (max_lines > 0 && tbuf->count_lines(0, tbuf->length()) >= max_lines) {
-			int le = tbuf->line_end(0) + 1; // plus 1 for the newline
-			tbuf->remove(0, le);
-			sbuf->remove(0, le);
-		}
-		// fall-through
-	default:
-		char s[] = { '\0', '\0', FTEXT_DEF + attr, '\0' };
-		const char *cp;
-
-		if ((c < ' ' || c == 127) && attr != CTRL) // look it up
-			cp = ascii[(unsigned char)c];
-		else { // insert verbatim
-			s[0] = c;
-			cp = &s[0];
-		}
-
-		for (int i = 0; cp[i]; ++i)
-			sbuf->append(s + 2);
-		insert(cp);
-		break;
-	}
-// test for bottom of text visibility
-	if (mTopLineNum + mNVisibleLines - 1 == mNBufferLines)
-//	if (mVScrollBar->value() >= mNBufferLines - mNVisibleLines + mVScrollBar->linesize() - 1)
-		show_insert_position();
-}
-#endif
 
 void FTextRX::set_quick_entry(bool b)
 {
@@ -429,10 +373,8 @@ void FTextRX::mark(FTextBase::TEXT_ATTR attr)
 void FTextRX::clear(void)
 {
 	FTextBase::clear();
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 	s_text.clear();
 	s_style.clear();
-#endif
 	static_cast<MVScrollbar*>(mVScrollBar)->clear();
 }
 
@@ -444,38 +386,22 @@ void FTextRX::setFont(Fl_Font f, int attr)
 
 void FTextRX::handle_clickable(int x, int y)
 {
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 	int pos;
 	unsigned int style;
-#else
-	int pos, style;
-#endif
 
 	pos = xy_to_position(x + this->x(), y + this->y(), CURSOR_POS);
 	// return unless clickable style
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 	if ((style = (unsigned char)sbuf->byte_at(pos)) < CLICK_START + FTEXT_DEF)
-#else
-	if ((style = sbuf->character(pos)) < CLICK_START + FTEXT_DEF)
-#endif
 		return;
 
 	int start, end;
 	for (start = pos-1; start >= 0; start--)
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 		if ((unsigned char)sbuf->byte_at(start) != style)
-#else
-		if (sbuf->character(start) != style)
-#endif
 			break;
 	start++;
 	int len = sbuf->length();
 	for (end = pos+1; end < len; end++)
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 		if ((unsigned char)sbuf->byte_at(end) != style)
-#else
-		if (sbuf->character(end) != style)
-#endif
 			break;
 
 	switch (style - FTEXT_DEF) {
@@ -687,8 +613,7 @@ void FTextRX::menu_cb(size_t item)
 		break;
 
 	case RX_MENU_WRAP:
-		set_word_wrap(!wrap);
-		restore_wrap = wrap;
+		set_word_wrap(!wrap, true);
 		break;
 
 	case RX_MENU_SCROLL_HINTS:
@@ -899,13 +824,8 @@ void FTextTX::clear(void)
 ///
 void FTextTX::clear_sent(void)
 {
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
  	tbuf->remove(0, utf8_txpos);
  	sbuf->remove(0, utf8_txpos);
-#else
-	tbuf->remove(0, txpos);
-	sbuf->remove(0, txpos);
-#endif
 	txpos = 0;
 	utf8_txpos = 0;
 	bkspaces = 0;
@@ -939,7 +859,6 @@ int FTextTX::nextChar(void)
 	else if (PauseBreak) {
 		PauseBreak = false;
 		c = GET_TX_CHAR_ETX;//0x03;
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 	} else if (insert_position() <= utf8_txpos) { // empty buffer or cursor inside transmitted text
 		c = -1;
 	} else {
@@ -952,15 +871,6 @@ int FTextTX::nextChar(void)
 			utf8_txpos += n;
 		} else
 			c = -1;
-#else
-	} else if (insert_position() <= txpos) { // empty buffer or cursor inside transmitted text
-		c = -1;
-	} else {
-		if ((c = static_cast<unsigned char>(tbuf->character(txpos)))) {
-			REQ(FTextTX::changed_cb, txpos, 0, 0, -1, static_cast<const char *>(0), this);
-			++txpos;
-		}
-#endif
 	}
 	return c;
 }
@@ -976,11 +886,9 @@ void FTextTX::add_text(string s)
 				if (ipos > 0 && txpos == ipos) {
 					bkspaces++;
 					txpos--;
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 					int nn;
 					tbuf->get_char_at(utf8_txpos, nn);
 					utf8_txpos -= nn;
-#endif
 				}
 				tbuf->remove(tbuf->length() - 1, tbuf->length());
 				sbuf->remove(sbuf->length() - 1, sbuf->length());
@@ -1150,7 +1058,6 @@ int FTextTX::handle_key(int key)
 		// In CW mode: Tab pauses, skips rest of buffer, applies the
 		// SKIP style, then resumes sending when new text is entered.
 		// Ctrl-tab does the same thing as for all other modes.
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 		if (utf8_txpos != insert_position())
 			insert_position(utf8_txpos);
 		else
@@ -1165,19 +1072,6 @@ int FTextTX::handle_key(int key)
 			redisplay_range(utf8_txpos, insert_position());
 			utf8_txpos = insert_position();
 		}
-#else
-		insert_position(txpos != insert_position() ? txpos : tbuf->length());
-		if (!(Fl::event_state() & FL_CTRL) && active_modem == cw_modem) {
-			int n = tbuf->length() - txpos;
-			char s[n + 1];
-			memset(s, FTEXT_DEF + SKIP, n);
-			s[n] = 0;
-			sbuf->replace(txpos, sbuf->length(), s);
-			insert_position(tbuf->length());
-			redisplay_range(txpos, insert_position());
-			txpos = insert_position();
-		}
-#endif
 		return 1;
 	// Move cursor, or search up/down with the Meta/Alt modifiers
 	case FL_Left:
@@ -1196,20 +1090,11 @@ int FTextTX::handle_key(int key)
 	case FL_BackSpace:
 	{
 		int ipos = insert_position();
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 		if (utf8_txpos > 0 && utf8_txpos == ipos) {
 			bkspaces++;
 			utf8_txpos = tbuf->prev_char(ipos);
 			txpos--;
 		}
-#else
-		if (txpos > 0 && txpos >= ipos) {
-			if (tbuf->length() >= txpos && txpos > ipos)
-				return 1;
-			bkspaces++;
-			txpos--;
-		}
-#endif
 		return 0;
 	}
 // alt - 1 / 2 changes macro sets
@@ -1388,8 +1273,7 @@ void FTextTX::menu_cb(size_t item)
 		break;
 	}
 	case TX_MENU_WRAP:
-		set_word_wrap(!wrap);
-		restore_wrap = wrap;
+		set_word_wrap(!wrap, true);
 		break;
 	}
 }
