@@ -81,7 +81,7 @@ pskBrowser::pskBrowser(int x, int y, int w, int h, const char *l)
 		bline = freqformat(i);
 		if ( i < progdefaults.VIEWERchannels) add(bline.c_str());
 		linechars[i] = 0;
-		new(&cdistiller[i]) CharsetDistiller(rxtx_charset);
+		new(&cdistiller[i]) CharsetDistiller;
 	}
 	nchars = (w - cols[0] - (sbarwidth + 2*BWSR_BORDER)) / cwidth;
 	nchars = nchars < 1 ? 1 : nchars;
@@ -250,11 +250,7 @@ void pskBrowser::addchr(int ch, int freq, unsigned char c, int md) // 0 < ch < c
 	if (linechars[ch] > nchars) {
 		if (progdefaults.VIEWERmarquee) {
 			while (linechars[ch] > nchars) {
-#if FLDIGI_FLTK_API_MAJOR == 1 && FLDIGI_FLTK_API_MINOR == 3
 				bwsrline[ch].erase(0, fl_utf8len1(bwsrline[ch][0]));
-#else
-				bwsrline[ch].erase(0, 1);
-#endif
 				linechars[ch]--;
 			}
 		} else {
