@@ -1,6 +1,25 @@
+// ----------------------------------------------------------------------------
 //
 // XmlRpc++ Copyright (c) 2002-2008 by Chris Morley
 //
+// Copyright (C) 2014
+//              David Freese, W1HKJ
+//
+// This file is part of fldigi
+//
+// fldigi is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or
+// (at your option) any later version.
+//
+// fldigi is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// ----------------------------------------------------------------------------
 
 #include <config.h>
 
@@ -231,10 +250,14 @@ namespace XmlRpc {
     }
 
     // No type tag? Assume string
-    bool result = true;
+//    bool result = true;
+    bool result = false;
+
     int valueOffset = *offset;
+
     if (XmlRpcUtil::nextTagIsEnd(VALUE_TAG, valueXml, offset))
     {
+      result = true;
       return stringFromXml(valueXml, &valueOffset);
     }
     else if (XmlRpcUtil::nextTagIs(NIL_TAG, valueXml, offset, &emptyTag))
@@ -244,41 +267,46 @@ namespace XmlRpc {
     }
     else if (XmlRpcUtil::nextTagIs(BOOLEAN_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = false;
-      else
+        result = true;
+      } else
         result = boolFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(BOOLEAN_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(I4_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = 0;
-      else
+        result = true;
+      } else
         result = intFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(I4_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(INT_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = 0;
-      else
+        result = true;
+      } else
         result = intFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(INT_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(DOUBLE_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = 0.0;
-      else
+        result = true;
+      } else
         result = doubleFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(DOUBLE_TAG, valueXml, offset);
     }
     else if (XmlRpcUtil::nextTagIs(STRING_TAG, valueXml, offset, &emptyTag))
     {
-      if (emptyTag)
+      if (emptyTag) {
         *this = "";
-      else
+        result = true;
+      } else
         result = stringFromXml(valueXml, offset) && 
                  XmlRpcUtil::nextTagIsEnd(STRING_TAG, valueXml, offset);
     }
